<?php
/**
 * Exit if accessed directly
 *
 * @package WooCommerce Ultimate Points And Rewards
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'MWB_WPR_Admin_Manager' ) ) {

	/**
	 * This class is used to manage admin settings
	 *
	 * @name    MWB_WPR_Admin_Manager
	 * @category Class
	 * @author   makewebbetter <webmaster@makewebbetter.com>
	 */
	class MWB_WPR_Admin_Manager {


		/**
		 * This is construct of class where all action and filter is defined
		 *
		 * @name __construct
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function __construct() {
			add_action( 'admin_menu', array( $this, 'mwb_wpr_admin_menu' ), 10, 2 );
			add_action( 'admin_enqueue_scripts', array( $this, 'mwb_wpr_admin_enqueue_scripts' ) );
			add_action( 'transition_comment_status', array( $this, 'mwb_wpr_give_points_on_comment' ), 10, 3 );

			add_filter( 'woocommerce_product_data_tabs', array( $this, 'mwb_wpr_add_points_tab' ), 15, 1 );

			add_action( 'woocommerce_product_data_panels', array( $this, 'mwb_wpr_points_input' ) );
			add_action( 'woocommerce_process_product_meta', array( $this, 'woo_add_custom_points_fields_save' ) );
			add_action( 'wp_ajax_mwb_wpr_points_update', array( $this, 'mwb_wpr_points_update' ) );
			add_action( 'wp_ajax_nopriv_mwb_wpr_points_update', array( $this, 'mwb_wpr_points_update' ) );
			add_action( 'wp_ajax_mwb_wpr_select_category', array( $this, 'mwb_wpr_select_category' ) );
			add_action( 'wp_ajax_nopriv_mwb_wpr_select_category', array( $this, 'mwb_wpr_select_category' ) );
			add_action( 'wp_ajax_mwb_wpr_per_pro_category', array( $this, 'mwb_wpr_per_pro_category' ) );
			add_action( 'wp_ajax_nopriv_mwb_wpr_per_pro_category', array( $this, 'mwb_wpr_per_pro_category' ) );
			add_action( 'wp_ajax_mwb_wpr_per_pro_pnt_category', array( $this, 'mwb_wpr_per_pro_pnt_category' ) );
			add_action( 'wp_ajax_nopriv_mwb_wpr_per_pro_pnt_category', array( $this, 'mwb_wpr_per_pro_pnt_category' ) );
			add_action( 'woocommerce_store_api_checkout_order_processed', array( $this, 'mwb_wpr_woocommerce_checkout_update_order_meta' ) );
			add_action( 'woocommerce_checkout_update_order_meta', array( $this, 'mwb_wpr_woocommerce_checkout_update_order_meta' ) );
			add_action( 'mwb_wpr_membership_cron_schedule', array( $this, 'mwb_wpr_do_this_hourly' ) );
			add_action( 'widgets_init', array( $this, 'mwb_wpr_custom_widgets' ) );
			add_action( 'woocommerce_admin_order_item_headers', array( $this, 'mwb_wpr_woocommerce_admin_order_item_headers' ) );
			add_action( 'woocommerce_admin_order_item_values', array( $this, 'mwb_wpr_woocommerce_admin_order_item_values' ), 10, 3 );
			add_action( 'woocommerce_variation_options', array( $this, 'mwb_wpr_woocommerce_variation_options_pricing' ), 10, 3 );
			add_action( 'woocommerce_save_product_variation', array( $this, 'mwb_wpr_woocommerce_save_product_variation' ), 10, 2 );
			add_action( 'wp_loaded', array( $this, 'mwb_wpr_check_daily_about_points_expiration' ), 10 );
			add_action( 'wp_ajax_mwb_wpr_register_license', array( $this, 'mwb_wpr_register_license' ) );
			add_action( 'wp_initialize_site', 'par_standard_plugin_on_create_new_blog', 900 );
			add_filter( 'plugin_row_meta', array( $this, 'mwb_wpr_custom_plugin_codecanyon' ), 10, 2 );
			// remove membership from user account.
			add_action( 'wp_ajax_mwb_wpr_remove__membership', array( $this, 'mwb_wpr_remove__membership_funs' ) );
			add_action( 'wp_ajax_nopriv_mwb_wpr_remove__membership', array( $this, 'mwb_wpr_remove__membership_funs' ) );

			// Show points in WP User Table.
			add_filter( 'manage_users_columns', array( $this, 'mwb_wpr_add_column' ) );
			add_filter( 'manage_users_custom_column', array( $this, 'mwb_wpr_column_content' ), 10, 3 );

			// preview csv file data.
			add_action( 'wp_ajax_mwb_wpr_preview_csv_data_action', array( $this, 'mwb_wpr_preview_csv_data_action_callback' ) );

			// subscription compatible hook.
			add_action( 'wps_sfw_compatible_points_and_rewards', array( $this, 'mwb_wpr_rewards_subcription_renewal_points' ), 10, 1 );
			add_action( 'woocommerce_order_status_changed', array( $this, 'mwb_wpr_deduct_subs_renewal_points' ), 10, 3 );
		}

		/**
		 * This function is used to remove membership from user account.
		 *
		 * @return void
		 */
		public function mwb_wpr_remove__membership_funs() {
			check_ajax_referer( 'mwb-wpr-verify-nonce', 'mwb_nonce' );
			if ( isset( $_POST ) && ! empty( $_POST ) ) {
				$wps_level_name = ! empty( $_POST['level_name'] ) ? sanitize_text_field( wp_unslash( $_POST['level_name'] ) ) : '';

				$args['meta_query'] = array(
					array(
						'key'     => 'membership_level',
						'compare' => 'EXISTS',
					),
				);

				$user_data = new WP_User_Query( $args );
				$user_data = $user_data->get_results();

				if ( ! empty( $user_data ) && is_array( $user_data ) ) {
					foreach ( $user_data as $keys => $values ) {
						$user_level = get_user_meta( $values->data->ID, 'membership_level', true );
						if ( ! empty( $wps_level_name ) && ! empty( $user_level ) ) {
							if ( $wps_level_name == $user_level ) {
								delete_user_meta( $values->data->ID, 'membership_level' );
							}
						}
					}
				}
			}
			wp_die();
		}

		/**
		 * This function is used for the importing the user points
		 *
		 * @name import_users_from_the_csv
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function import_users_from_the_csv() {
			if ( isset( $_POST['mwb_file_submit'] ) && ! empty( $_POST['mwb_wpr_nonce'] ) && ! empty( $_FILES['csv_file'] ) ) {
				$mwb_wpr_nonce = sanitize_text_field( wp_unslash( $_POST['mwb_wpr_nonce'] ) );
				if ( ! empty( $_POST['mwb_wpr_nonce'] ) && wp_verify_nonce( $mwb_wpr_nonce, 'mwb_upload_csv' ) ) {
					$csv_file = sanitize_text_field( wp_unslash( $_FILES['csv_file'] ) );
					/* Get the points of the user*/
					$csv_to_array  = array_map( 'str_getcsv', file( $csv_file['tmp_name'] ) );
					if ( ! empty( $csv_to_array ) && is_array( $csv_to_array ) ) {
						$sign = '+';
						foreach ( $csv_to_array as $key => $value ) {
							if ( 0 == $key ) {
								$user_email  = $value['0'];
								$user_points = $value['1'];
							} else {
								$user_email = $value['0'];
								$points     = $value['1'];
								$reason     = $value['2'];
								$user       = get_user_by( 'email', $user_email );
								if ( isset( $user ) ) {
									$user_id = $user->ID;
									if ( empty( $points ) ) {
										$points = 0;
									}
									update_user_meta( $user_id, 'mwb_wpr_points', $points );
									$admin_points = get_user_meta( $user_id, 'points_details', true );
									$today_date   = date_i18n( 'Y-m-d h:i:sa' );
									if ( isset( $points ) && ! empty( $points ) ) {

										if ( isset( $admin_points['admin_points'] ) && ! empty( $admin_points['admin_points'] ) ) {
											$admin_array                    = array();
											$admin_array                    = array(
												'admin_points' => $points,
												'date'   => $today_date,
												'sign'   => $sign,
												'reason' => $reason,
											);
											$admin_points['admin_points'][] = $admin_array;
										} else {
											if ( ! is_array( $admin_points ) ) {
												$admin_points = array();
											}
											$admin_array                    = array(
												'admin_points' => $points,
												'date'   => $today_date,
												'sign'   => $sign,
												'reason' => $reason,
											);
											$admin_points['admin_points'][] = $admin_array;
										}
									}
									update_user_meta( $user_id, 'points_details', $admin_points );
								}
							}
						}
					}
				}
			}
		}

		/**
		 * This function update points
		 *
		 * @name mwb_wpr_points_update
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function mwb_wpr_points_update() {
			check_ajax_referer( 'mwb-wpr-verify-nonce', 'mwb_nonce' );
			if ( isset( $_POST['points'] ) && is_numeric( $_POST['points'] ) ) {
				$user_id      = isset( $_POST['user_id'] ) ? sanitize_text_field( wp_unslash( $_POST['user_id'] ) ) : '';
				$get_points   = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
				$admin_points = get_user_meta( $user_id, 'points_details', true );
				$today_date   = date_i18n( 'Y-m-d h:i:sa' );
				$points       = sanitize_text_field( wp_unslash( $_POST['points'] ) );
				$sign         = isset( $_POST['sign'] ) ? sanitize_text_field( wp_unslash( $_POST['sign'] ) ) : '';
				$reason       = isset( $_POST['reason'] ) ? sanitize_text_field( wp_unslash( $_POST['reason'] ) ) : '';
				if ( '+' === $sign ) {
					$total_points = $get_points + $points;
				} elseif ( '-' === $sign ) {
					if ( $points <= $get_points ) {
						$total_points = $get_points - $points;
					} else {
						$points = $get_points;
					}
						$total_points = $get_points - $points;
				}
				if ( isset( $points ) && ! empty( $points ) ) {

					if ( isset( $admin_points['admin_points'] ) && ! empty( $admin_points['admin_points'] ) ) {
						$admin_array                    = array();
						$admin_array                    = array(
							'admin_points' => $points,
							'date'         => $today_date,
							'sign'         => $sign,
							'reason'       => $reason,
						);
						$admin_points['admin_points'][] = $admin_array;
					} else {
						if ( ! is_array( $admin_points ) ) {
							$admin_points = array();
						}
						$admin_array                    = array(
							'admin_points' => $points,
							'date'         => $today_date,
							'sign'         => $sign,
							'reason'       => $reason,
						);
						$admin_points['admin_points'][] = $admin_array;
					}
				}
				update_user_meta( $user_id, 'points_details', $admin_points );
				update_user_meta( $user_id, 'mwb_wpr_points', $total_points );
				$user                      = get_user_by( 'ID', $user_id );
				$user_email                = $user->user_email;
				$user_name                 = $user->user_firstname;
				$mwb_wpr_notificatin_array = get_option( 'mwb_wpr_notificatin_array', true );
				if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
					$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
					$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_email_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_email_subject'] : '';
					$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_email_discription_custom_id'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_email_discription_custom_id'] : '';
					$mwb_wpr_email_discription  = str_replace( '[Total Points]', $total_points, $mwb_wpr_email_discription );
					$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
					if ( $mwb_wpr_notificatin_enable ) {
						$headers = array( 'Content-Type: text/html; charset=UTF-8' );
						wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
					}
				}
			}
			wp_die();
		}

		/**
		 * This function update product custom points.
		 *
		 * @param      string $post_id       Data.
		 * @name woo_add_custom_points_fields_save
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function woo_add_custom_points_fields_save( $post_id ) {
			$value_check              = isset( $_POST['message-sent-admin'] ) ? sanitize_text_field( wp_unslash( $_POST['message-sent-admin'] ) ) : '';
			$mwb_product_hidden_field = isset( $_POST['mwb_product_hidden_field'] ) ? sanitize_text_field( wp_unslash( $_POST['mwb_product_hidden_field'] ) ) : '';
			if ( isset( $mwb_product_hidden_field ) && wp_verify_nonce( $value_check, 'admin-action' ) ) {

				$general_settings_array         = array();
				$enable_product_points          = isset( $_POST['mwb_product_points_enable'] ) ? sanitize_text_field( wp_unslash( $_POST['mwb_product_points_enable'] ) ) : 'no';
				$enable_product_purchase_points = isset( $_POST['mwb_product_purchase_points_only'] ) ? sanitize_text_field( wp_unslash( $_POST['mwb_product_purchase_points_only'] ) ) : 'no';
				$mwb_pro_pur_by_point_disable   = isset( $_POST['mwb_product_purchase_through_point_disable'] ) ? sanitize_text_field( wp_unslash( $_POST['mwb_product_purchase_through_point_disable'] ) ) : 'no';
				$mwb_product_value              = ( isset( $_POST['mwb_points_product_value'] ) && null !== $_POST['mwb_points_product_value'] ) ? sanitize_text_field( wp_unslash( $_POST['mwb_points_product_value'] ) ) : 1;
				$mwb_product_purchase_value     = ( isset( $_POST['mwb_points_product_purchase_value'] ) && null !== $_POST['mwb_points_product_purchase_value'] ) ? sanitize_text_field( wp_unslash( $_POST['mwb_points_product_purchase_value'] ) ) : 1;
				update_post_meta( $post_id, 'mwb_product_points_enable', $enable_product_points );
				update_post_meta( $post_id, 'mwb_product_purchase_points_only', $enable_product_purchase_points );
				update_post_meta( $post_id, 'mwb_points_product_value', $mwb_product_value );
				update_post_meta( $post_id, 'mwb_points_product_purchase_value', $mwb_product_purchase_value );
				update_post_meta( $post_id, 'mwb_product_purchase_through_point_disable', $mwb_pro_pur_by_point_disable );
			}
		}

		/**
		 * This construct set products point.
		 *
		 * @name mwb_wpr_points_input
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function mwb_wpr_points_input() {
			global $post;
			$product_is_variable = false;
			$product             = wc_get_product( $post->ID );
			if ( $product->is_type( 'variable' ) && $product->has_child() ) {
				$product_is_variable = true;
			}
			?>
				<div id="points_data" class="panel woocommerce_options_panel">
					<div class="options_group">
					<?php
						woocommerce_wp_checkbox(
							array(
								'id'            => 'mwb_product_points_enable',
								'wrapper_class' => 'show_if_points',
								'label'         => __( 'Enable', 'woocommerce-ultimate-points-and-rewards' ),
								'description'   => __(
									'Enable Points Per Product',
									'woocommerce-ultimate-points-and-rewards'
								),
							)
						);
					if ( ! $product_is_variable ) {
							woocommerce_wp_text_input(
								array(
									'id'                => 'mwb_points_product_value',
									'label'             => __( 'Enter the Points', 'woocommerce-ultimate-points-and-rewards' ),
									'desc_tip'          => true,
									'custom_attributes' => array( 'min' => '0' ),
									'description'       => __( 'Please enter the number of points for this product ', 'woocommerce-ultimate-points-and-rewards' ),
									'type'              => 'number',
								)
							);
					}
						woocommerce_wp_checkbox(
							array(
								'id'            => 'mwb_product_purchase_through_point_disable',
								'wrapper_class' => 'show_if_points',
								'label'         => __( 'Do not allow to purchase through points', 'woocommerce-ultimate-points-and-rewards' ),
								'description'   => __(
									'Do not allow to purchase this product through points',
									'woocommerce-ultimate-points-and-rewards'
								),
							)
						);

						// MWB Custom Work.

						woocommerce_wp_checkbox(
							array(
								'id'            => 'mwb_product_purchase_points_only',
								'wrapper_class' => 'show_if_points_only',
								'label'         => __( 'Enable', 'woocommerce-ultimate-points-and-rewards' ),
								'description'   => __(
									'Enable Purchase through points only',
									'woocommerce-ultimate-points-and-rewards'
								),
							)
						);
					if ( ! $product_is_variable ) {
							woocommerce_wp_text_input(
								array(
									'id'                => 'mwb_points_product_purchase_value',
									'label'             => __( 'Enter the Points For Purchase', 'woocommerce-ultimate-points-and-rewards' ),
									'desc_tip'          => true,
									'custom_attributes' => array( 'min' => '0' ),
									'description'       => __( 'Please enter the number of points for purchase this product ', 'woocommerce-ultimate-points-and-rewards' ),
									'type'              => 'number',
								)
							);
					}
					// End of Custom Work.
					?>
						<input type="hidden" name="mwb_product_hidden_field"></input>
						<?php $nonce = wp_create_nonce( 'admin-action' ); ?>
						<input type="hidden" name="message-sent-admin" value="<?php echo esc_attr( $nonce ); ?>" />
					</div>
				</div>
			<?php

		}

		/**
		 * This construct add tab in products menu.
		 *
		 * @param      string $all_tabs       Data.
		 * @name mwb_wpr_add_points_tab
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function mwb_wpr_add_points_tab( $all_tabs ) {
			$all_tabs['points'] = array(
				'label'  => __( 'Points and Rewards', 'woocommerce-ultimate-points-and-rewards' ),
				'target' => 'points_data',
			);
			return $all_tabs;
		}

		/**
		 * This function update points on comment.
		 *
		 * @param      string $new_status       Data.
		 * @param      string $old_status       Data.
		 * @param      object $comment       Data.
		 * @name mwb_wpr_give_points_on_comment
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function mwb_wpr_give_points_on_comment( $new_status, $old_status, $comment ) {
			global $current_user;
			$user_email = $comment->comment_author_email;

			if ( 'approved' === $new_status ) {
				$general_settings = get_option( 'mwb_wpr_settings_gallery', true );

				$enable_mwb_comment = isset( $general_settings['enable_mwb_comment'] ) ? intval( $general_settings['enable_mwb_comment'] ) : 0;

				if ( $enable_mwb_comment ) {

					$today_date        = date_i18n( 'Y-m-d h:i:sa' );
					$mwb_comment_value = isset( $general_settings['mwb_comment_value'] ) ? intval( $general_settings['mwb_comment_value'] ) : 1;

					$get_points       = get_user_meta( $comment->user_id, 'mwb_wpr_points', true );
					$get_detail_point = get_user_meta( $comment->user_id, 'points_details', true );

					if ( isset( $get_detail_point['comment'] ) && ! empty( $get_detail_point['comment'] ) ) {
						$comment_arr = array();

						$comment_arr                   = array(
							'comment' => $mwb_comment_value,
							'date'    => $today_date,
						);
						$get_detail_point['comment'][] = $comment_arr;

					} else {
						if ( ! is_array( $get_detail_point ) ) {
							$get_detail_point = array();
						}
						$comment_arr = array(
							'comment' => $mwb_comment_value,
							'date'    => $today_date,
						);

						$get_detail_point['comment'][] = $comment_arr;
					}
					update_user_meta( $comment->user_id, 'mwb_wpr_points', $mwb_comment_value + $get_points );

					update_user_meta( $comment->user_id, 'points_details', $get_detail_point );

					$mwb_wpr_notificatin_array = get_option( 'mwb_wpr_notificatin_array', true );
					if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
						$total_points               = $mwb_comment_value + $get_points;
						$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
						$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_comment_email_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_comment_email_subject'] : '';
						$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_comment_email_discription_custom_id'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_comment_email_discription_custom_id'] : '';
						$mwb_wpr_email_discription  = str_replace( '[Points]', $mwb_comment_value, $mwb_wpr_email_discription );
						$mwb_wpr_email_discription  = str_replace( '[Total Points]', $total_points, $mwb_wpr_email_discription );
						$user                       = get_user_by( 'email', $user_email );
						$user_name                  = $user->user_firstname;
						$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
						if ( $mwb_wpr_notificatin_enable ) {
							$headers = array( 'Content-Type: text/html; charset=UTF-8' );
							wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
						}
					}
				}
			}
		}

		/**
		 * This function enque admin script.
		 *
		 * @name mwb_wpr_admin_enqueue_scripts.
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function mwb_wpr_admin_enqueue_scripts() {
			$screen = get_current_screen();

			if ( isset( $screen->id ) ) {
				$pagescreen = $screen->id;

				if ( isset( $_GET['page'] ) && 'mwb-wpr-setting' === $_GET['page'] || 'product' === $pagescreen ) {

					wp_register_style( 'woocommerce_admin_styles', WC()->plugin_url() . '/assets/css/admin.css', array(), WC_VERSION );
					wp_enqueue_style( 'woocommerce_admin_menu_styles' );
					wp_enqueue_style( 'woocommerce_admin_styles' );
					wp_enqueue_style( 'wp-color-picker' );
					wp_enqueue_script( 'wp-color-picker' );
					wp_register_script( 'woocommerce_admin', WC()->plugin_url() . '/assets/js/admin/woocommerce_admin.js', array( 'jquery', 'jquery-blockui', 'jquery-ui-sortable', 'jquery-ui-widget', 'jquery-ui-core', 'jquery-tiptip' ), WC_VERSION );
					wp_register_script( 'jquery-tiptip', WC()->plugin_url() . '/assets/js/jquery-tiptip/jquery.tipTip.js', array( 'jquery' ), WC_VERSION, true );

					$locale  = localeconv();
					$decimal = isset( $locale['decimal_point'] ) ? $locale['decimal_point'] : '.';
					$params  = array(
						/* translators: %s: decimal */
						'i18n_decimal_error'               => sprintf( __( 'Please enter in decimal (%s) format without thousand separators.', 'woocommerce-ultimate-points-and-rewards' ), $decimal ),
						/* translators: %s: price decimal separator */
						'i18n_mon_decimal_error'           => sprintf( __( 'Please enter in monetary decimal (%s) format without thousand separators and currency symbols.', 'woocommerce-ultimate-points-and-rewards' ), wc_get_price_decimal_separator() ),
						'i18n_country_iso_error'           => __( 'Please enter in country code with two capital letters.', 'woocommerce-ultimate-points-and-rewards' ),
						'i18_sale_less_than_regular_error' => __( 'Please enter in a value less than the regular price.', 'woocommerce-ultimate-points-and-rewards' ),
						'decimal_point'                    => $decimal,
						'mon_decimal_point'                => wc_get_price_decimal_separator(),
						'strings'                          => array(
							'import_products' => __( 'Import', 'woocommerce-ultimate-points-and-rewards' ),
							'export_products' => __( 'Export', 'woocommerce-ultimate-points-and-rewards' ),
						),
						'urls'                             => array(
							'import_products' => esc_url_raw( admin_url( 'edit.php?post_type=product&page=product_importer' ) ),
							'export_products' => esc_url_raw( admin_url( 'edit.php?post_type=product&page=product_exporter' ) ),
						),
					);

					wp_localize_script( 'woocommerce_admin', 'woocommerce_admin', $params );
					wp_enqueue_script( 'woocommerce_admin' );
					wp_enqueue_style( 'mwb_wpr_admin_style', MWB_WPR_URL . 'assets/css/admin/woocommerce-ultimate-points-admin.min.css', array(), '2.7.1' );

					$args_cat     = array( 'taxonomy' => 'product_cat' );
					$categories   = get_terms( $args_cat );
					$option_arr   = array();
					$option_categ = array();
					if ( isset( $categories ) && ! empty( $categories ) ) {
						foreach ( $categories as $category ) {
							$catid   = $category->term_id;
							$catname = $category->name;

							$option_categ[] = array(
								'id'       => $catid,
								'cat_name' => $catname,
							);
						}
					}
					$url     = admin_url( 'admin.php?page=mwb-wpr-setting' );
					$mwb_wpr = array(
						'ajaxurl'           => admin_url( 'admin-ajax.php' ),
						'validpoint'        => __( 'Please enter valid points', 'woocommerce-ultimate-points-and-rewards' ),
						'Labelname'         => __( 'Enter the Name of the Level', 'woocommerce-ultimate-points-and-rewards' ),
						'Labeltext'         => __( 'Enter Level', 'woocommerce-ultimate-points-and-rewards' ),
						'Points'            => __( 'Enter Points', 'woocommerce-ultimate-points-and-rewards' ),
						'Categ_text'        => __( 'Select Product Category', 'woocommerce-ultimate-points-and-rewards' ),
						'Remove_text'       => __( 'Remove', 'woocommerce-ultimate-points-and-rewards' ),
						'Categ_option'      => ! empty( $option_categ ) ? $option_categ : '',
						'Prod_text'         => __( 'Select Product', 'woocommerce-ultimate-points-and-rewards' ),
						'Discounttext'      => __( 'Enter Discount (%)', 'woocommerce-ultimate-points-and-rewards' ),
						'error_notice'      => __( 'Fields cannot be empty', 'woocommerce-ultimate-points-and-rewards' ),
						'LevelName_notice'  => __( 'Please Enter the Name of the Level', 'woocommerce-ultimate-points-and-rewards' ),
						'LevelValue_notice' => __( 'Please Enter valid Points', 'woocommerce-ultimate-points-and-rewards' ),
						'CategValue_notice' => __( 'Please select a category', 'woocommerce-ultimate-points-and-rewards' ),
						'ProdValue_notice'  => __( 'Please select a product', 'woocommerce-ultimate-points-and-rewards' ),
						'Discount_notice'   => __( 'Please enter valid discount', 'woocommerce-ultimate-points-and-rewards' ),
						'success_assign'    => __( 'Points are assigned successfully!', 'woocommerce-ultimate-points-and-rewards' ),
						'error_assign'      => __( 'Enter Some Valid Points!', 'woocommerce-ultimate-points-and-rewards' ),
						'success_remove'    => __( 'Points are removed successfully!', 'woocommerce-ultimate-points-and-rewards' ),
						'Days'              => __( 'Days', 'woocommerce-ultimate-points-and-rewards' ),
						'Weeks'             => __( 'Weeks', 'woocommerce-ultimate-points-and-rewards' ),
						'Months'            => __( 'Months', 'woocommerce-ultimate-points-and-rewards' ),
						'Years'             => __( 'Years', 'woocommerce-ultimate-points-and-rewards' ),
						'Exp_period'        => __( 'Expiration Period', 'woocommerce-ultimate-points-and-rewards' ),
						'mwb_wpr_url'       => $url,
						'reason'            => __( 'Please enter Remark', 'woocommerce-ultimate-points-and-rewards' ),
						'mwb_wpr_nonce'     => wp_create_nonce( 'mwb-wpr-verify-nonce' ),
						'license_error_msg' => esc_html__( 'Something Went Wrong! Please try again', 'woocommerce-ultimate-points-and-rewards' ),
						'remove_button'     => esc_html__( 'Remove', 'woocommerce-ultimate-points-and-rewards' ),
						'empty_field_msg'   => esc_html__( 'Some Fields are empty!', 'woocommerce-ultimate-points-and-rewards' ),
						'min_max_error_msg' => esc_html__( 'Minimum value cannot have value grater than Maximim value', 'woocommerce-ultimate-points-and-rewards' ),
					);

					wp_register_script( 'mwb_wpr_admin_script', MWB_WPR_JS_LOAD_ADMIN, array( 'select2' ), '2.7.1' );
					wp_localize_script( 'mwb_wpr_admin_script', 'mwb_wpr', $mwb_wpr );
					wp_enqueue_script( 'mwb_wpr_admin_script' );
					wp_enqueue_style( 'select2' );
				}
			}
		}

		/**
		 * This function make woocommerce admin menu.
		 *
		 * @name mwb_wpr_admin_menu.
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function mwb_wpr_admin_menu() {

			// Remove the www from the Host Name.
			$host_server = isset( $_SERVER['HTTP_HOST'] ) ? sanitize_text_field( wp_unslash( $_SERVER['HTTP_HOST'] ) ) : '';
			if ( strpos( $host_server, 'www.' ) == 0 ) {

				$host_server = str_replace( 'www.', '', $host_server );
			}

			$mwb_wpr_license_hash   = get_option( 'mwb_wpr_license_hash' );
			$mwb_wpr_license_key    = get_option( 'mwb_wpr_license_key' );
			$mwb_wpr_license_plugin = get_option( 'mwb_wpr_plugin_name' );
			$mwb_wpr_hash           = md5( $host_server . $mwb_wpr_license_plugin . $mwb_wpr_license_key );
			$mwb_wpr_activated_time = get_option( 'mwb_wpr_activation_date_time', false );
			if ( ! $mwb_wpr_activated_time ) {
				$mwb_wpr_currenttime = current_time( 'timestamp' );
				update_option( 'mwb_wpr_activation_date_time', $mwb_wpr_currenttime );
				$mwb_wpr_activated_time = $mwb_wpr_currenttime;
			}
			$mwb_wpr_after_month = strtotime( '+30 days', $mwb_wpr_activated_time );
			$mwb_wpr_currenttime = current_time( 'timestamp' );

			if ( $mwb_wpr_license_hash == $mwb_wpr_hash ) {
				add_submenu_page( 'woocommerce', __( 'WooCommerce Points And Rewards Manager', 'woocommerce-ultimate-points-and-rewards' ), __( 'Points And Rewards Manager', 'woocommerce-ultimate-points-and-rewards' ), 'manage_woocommerce', 'mwb-wpr-setting', array( $this, 'mwb_wpr_admin_setting' ) );

			} elseif ( ( '' == $mwb_wpr_license_hash || '' == $mwb_wpr_license_key ) && ( $mwb_wpr_after_month > $mwb_wpr_currenttime ) ) {
				add_submenu_page( 'woocommerce', __( 'WooCommerce Points And Rewards Manager', 'woocommerce-ultimate-points-and-rewards' ), __( 'Points And Rewards Manager', 'woocommerce-ultimate-points-and-rewards' ), 'manage_woocommerce', 'mwb-wpr-setting', array( $this, 'mwb_wpr_admin_setting' ) );
			} else {
				$general_settings = get_option( 'mwb_wpr_settings_gallery', true );
				if ( is_array( $general_settings ) && array_key_exists( 'enable_mwb_wpr', $general_settings ) ) {
					$general_settings['enable_mwb_wpr'] = 0;
				}
				update_option( 'mwb_wpr_settings_gallery', $general_settings );
				add_submenu_page( 'woocommerce', __( 'WooCommerce Points And Rewards Manager', 'woocommerce-ultimate-points-and-rewards' ), __( 'Activate Points And Rewards Manager', 'woocommerce-ultimate-points-and-rewards' ), 'manage_woocommerce', 'mwb-wpr-setting', array( $this, 'mwb_wpr_admin_setting_activation' ) );
			}
		}

		/**
		 * This function make woocommerce admin menu settings.
		 *
		 * @name mwb_wpr_admin_setting.
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function mwb_wpr_admin_setting() {
			include_once MWB_WPR_DIRPATH . '/includes/admin/settings/woocommerce-ultimate-points-and-rewards-settings.php';
		}

		/**
		 * This function make woocommerce admin menu settings.
		 *
		 * @name mwb_wpr_admin_setting_activation.
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function mwb_wpr_admin_setting_activation() {
			include_once MWB_WPR_DIRPATH . '/includes/admin/settings/templates/mwb-license-verify.php';
		}

		/**
		 * This function append the option field after selecting Product category through ajax
		 *
		 * @name mwb_wpr_select_category.
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function mwb_wpr_select_category() {

			check_ajax_referer( 'mwb-wpr-verify-nonce', 'mwb_nonce' );
			$mwb_wpr_categ_list = isset( $_POST['mwb_wpr_categ_list'] ) ? sanitize_text_field( wp_unslash( $_POST['mwb_wpr_categ_list'] ) ) : '';
			$response['result'] = __( 'Fail due to an error', 'woocommerce-ultimate-points-and-rewards' );
			if ( isset( $_POST['mwb_wpr_categ_list'] ) ) {
				$products              = array();
				$selected_cat          = ! empty( $_POST['mwb_wpr_categ_list'] ) ? ( is_array( $_POST['mwb_wpr_categ_list'] ) ? map_deep( wp_unslash( $_POST['mwb_wpr_categ_list'] ), 'sanitize_text_field' ) : sanitize_text_field( wp_unslash( $_POST['mwb_wpr_categ_list'] ) ) ) : array();
				$tax_query['taxonomy'] = 'product_cat';
				$tax_query['field']    = 'id';
				$tax_query['terms']    = $selected_cat;
				$tax_queries[]         = $tax_query;
				$args                  = array(
					'post_type'      => 'product',
					'posts_per_page' => -1,
					'tax_query'      => $tax_queries,
					'orderby'        => 'rand',
				);
				$loop                  = new WP_Query( $args );
				while ( $loop->have_posts() ) :
					$loop->the_post();
					global $product;

					$product_id              = $loop->post->ID;
					$product_title           = $loop->post->post_title;
					$products[ $product_id ] = $product_title;
				endwhile;

				$response['data']   = $products;
				$response['result'] = 'success';
				echo json_encode( $response );
				wp_die();
			}
		}

		/**
		 * This function append the option field after selecting Product category through ajax in Assign Product Points Tab
		 *
		 * @name mwb_wpr_select_category.
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function mwb_wpr_per_pro_category() {
			check_ajax_referer( 'mwb-wpr-verify-nonce', 'mwb_nonce' );
			$mwb_wpr_categ_id    = isset( $_POST['mwb_wpr_categ_id'] ) ? sanitize_text_field( wp_unslash( $_POST['mwb_wpr_categ_id'] ) ) : '';
			$mwb_wpr_categ_point = isset( $_POST['mwb_wpr_categ_point'] ) ? sanitize_text_field( wp_unslash( $_POST['mwb_wpr_categ_point'] ) ) : '';
			$response['result']  = __( 'Fail due to an error', 'woocommerce-ultimate-points-and-rewards' );
			if ( isset( $mwb_wpr_categ_id ) && ! empty( $mwb_wpr_categ_id ) ) {
				$products              = array();
				$selected_cat          = $mwb_wpr_categ_id;
				$tax_query['taxonomy'] = 'product_cat';
				$tax_query['field']    = 'id';
				$tax_query['terms']    = $selected_cat;
				$tax_queries[]         = $tax_query;
				$args                  = array(
					'post_type'      => 'product',
					'posts_per_page' => -1,
					'tax_query'      => $tax_queries,
					'orderby'        => 'rand',
				);
				$loop                  = new WP_Query( $args );
				while ( $loop->have_posts() ) :
					$loop->the_post();
					global $product;

					$product_id    = $loop->post->ID;
					$product_title = $loop->post->post_title;
					if ( isset( $mwb_wpr_categ_point ) && ! empty( $mwb_wpr_categ_point ) ) {
						$product = wc_get_product( $product_id );
						if ( $product->is_type( 'variable' ) && $product->has_child() ) {
							$parent_id      = $product->get_id();
							$parent_product = wc_get_product( $parent_id );
							foreach ( $parent_product->get_children() as $child_id ) {
								update_post_meta( $parent_id, 'mwb_product_points_enable', 'yes' );
								update_post_meta( $child_id, 'mwb_wpr_variable_points', $mwb_wpr_categ_point );
							}
						} else {
							update_post_meta( $product_id, 'mwb_product_points_enable', 'yes' );
							update_post_meta( $product_id, 'mwb_points_product_value', $mwb_wpr_categ_point );
							update_option( 'mwb_wpr_points_to_per_categ_' . $mwb_wpr_categ_id, $mwb_wpr_categ_point );
						}
					} else {
						update_post_meta( $product_id, 'mwb_product_points_enable', 'no' );
						update_post_meta( $product_id, 'mwb_points_product_value', '' );
						update_option( 'mwb_wpr_points_to_per_categ_' . $mwb_wpr_categ_id, $mwb_wpr_categ_point );
					}
				endwhile;
				$response['category_id'] = $mwb_wpr_categ_id;
				$response['categ_point'] = $mwb_wpr_categ_point;
				$response['result']      = 'success';
				echo json_encode( $response );
				wp_die();
			}
		}

		/**
		 * This function append the option field after selecting Product category through ajax in Product Purchase Points Tab
		 *
		 * @name mwb_wpr_per_pro_pnt_category.
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function mwb_wpr_per_pro_pnt_category() {
			check_ajax_referer( 'mwb-wpr-verify-nonce', 'mwb_nonce' );
			$mwb_wpr_categ_id    = isset( $_POST['mwb_wpr_categ_id'] ) ? sanitize_text_field( wp_unslash( $_POST['mwb_wpr_categ_id'] ) ) : '';
			$mwb_wpr_categ_point = isset( $_POST['mwb_wpr_categ_point'] ) ? sanitize_text_field( wp_unslash( $_POST['mwb_wpr_categ_point'] ) ) : '';
			$response['result']  = __( 'Fail due to an error', 'woocommerce-ultimate-points-and-rewards' );
			if ( isset( $mwb_wpr_categ_id ) && ! empty( $mwb_wpr_categ_id ) ) {
				$products              = array();
				$selected_cat          = $mwb_wpr_categ_id;
				$tax_query['taxonomy'] = 'product_cat';
				$tax_query['field']    = 'id';
				$tax_query['terms']    = $selected_cat;
				$tax_queries[]         = $tax_query;
				$args                  = array(
					'post_type'      => 'product',
					'posts_per_page' => -1,
					'tax_query'      => $tax_queries,
					'orderby'        => 'rand',
				);
				$loop                  = new WP_Query( $args );
				while ( $loop->have_posts() ) :
					$loop->the_post();
					global $product;

					$product_id    = $loop->post->ID;
					$product_title = $loop->post->post_title;
					if ( isset( $mwb_wpr_categ_point ) && ! empty( $mwb_wpr_categ_point ) ) {
						$product = wc_get_product( $product_id );
						if ( $product->is_type( 'variable' ) && $product->has_child() ) {
							$parent_id      = $product->get_id();
							$parent_product = wc_get_product( $parent_id );
							foreach ( $parent_product->get_children() as $child_id ) {
								update_post_meta( $parent_id, 'mwb_product_purchase_points_only', 'yes' );
								update_post_meta( $child_id, 'mwb_wpr_variable_points_purchase', $mwb_wpr_categ_point );
							}
						} else {
							update_post_meta( $product_id, 'mwb_product_purchase_points_only', 'yes' );
							update_post_meta( $product_id, 'mwb_points_product_purchase_value', $mwb_wpr_categ_point );
							update_option( 'mwb_wpr_purchase_points_cat' . $mwb_wpr_categ_id, $mwb_wpr_categ_point );                                           }
					} else {
						update_post_meta( $product_id, 'mwb_product_purchase_points_only', 'no' );
						update_post_meta( $product_id, 'mwb_points_product_purchase_value', '' );
						update_option( 'mwb_wpr_purchase_points_cat' . $mwb_wpr_categ_id, $mwb_wpr_categ_point );
					}
				endwhile;
				$response['category_id'] = $mwb_wpr_categ_id;
				$response['categ_point'] = $mwb_wpr_categ_point;
				$response['result']      = 'success';
				echo json_encode( $response );
				wp_die();
			}
		}

		/**
		 * This function will update the user points as they purchased products through points.
		 *
		 * @param  object $order_data order.
		 * @return void
		 */
		public function mwb_wpr_woocommerce_checkout_update_order_meta( $order_data ) {

			// This function is triggered by two hooks, so we need to verify whether the parameter is an ID or an object.
			if ( ! is_object( $order_data ) ) {
				$order = wc_get_order( $order_data );
			} else {
				$order = $order_data;
			}

			$user_id = $order->get_user_id();
			if ( empty( $user_id ) ) {
				return;
			}

			$user                           = get_user_by( 'ID', $user_id );
			$user_email                     = $user->user_email;
			$woo_ver                        = WC()->version;
			$deduct_point                   = '';
			$points_deduct                  = 0;
			$mwb_wpr_is_pnt_fee_applied     = false;
			$mwb_wpr_notificatin_array      = get_option( 'mwb_wpr_notificatin_array', true );
			$get_points                     = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
			$pur_by_points                  = get_user_meta( $user_id, 'points_details', true );
			$pur_by_points                  = ! empty( $pur_by_points ) && is_array( $pur_by_points ) ? $pur_by_points : array();
			$general_settings               = get_option( 'mwb_wpr_settings_gallery', true );
			$mwb_wpr_purchase_points        = ( isset( $general_settings['mwb_wpr_purchase_points'] ) && null !== $general_settings['mwb_wpr_purchase_points'] ) ? $general_settings['mwb_wpr_purchase_points'] : 1;
			$mwb_wpr_product_purchase_price = ( isset( $general_settings['mwb_wpr_product_purchase_price'] ) && null !== $general_settings['mwb_wpr_product_purchase_price'] ) ? intval( $general_settings['mwb_wpr_product_purchase_price'] ) : 1;

			$today_date     = date_i18n( 'Y-m-d h:i:sa' );
			$total_points   = '';
			$order_id       = $order->get_id();
			$line_items_fee = $order->get_items( 'fee' );
			if ( ! empty( $line_items_fee ) ) {
				foreach ( $line_items_fee as $item_id => $item ) {
					if ( $woo_ver < '3.0.0' ) {
						$mwb_wpr_fee_name = $item['name'];
					} else {
						$mwb_wpr_fee_name = $item->get_name();
					}
					if ( 'Point Discount' === $mwb_wpr_fee_name ) {
						$mwb_wpr_is_pnt_fee_applied = true;
						$fee_amount                 = $item->get_amount();
					}
				}
			}

			$woo_ver = WC()->version;
			if ( $woo_ver < '3.0.0' ) {
				foreach ( $order->get_items() as $item_id => $item ) {
					$item_quantity = $order->get_item_meta( $item_id, '_qty', true );
					if ( isset( $item['item_meta']['Purchasing Option'] ) && ! empty( $item['item_meta']['Purchasing Option'] ) ) {
						if ( $mwb_wpr_is_pnt_fee_applied ) {
							$deduct_point += (int) $item['item_meta']['Purchasing Option'][0];
							$total_points  = $get_points - $deduct_point;
							if ( isset( $pur_by_points['pur_by_points'] ) && ! empty( $pur_by_points['pur_by_points'] ) ) {
								$pur_by_point_arr                 = array(
									'pur_by_points' => $deduct_point,
									'date'          => $today_date,
								);
								$pur_by_points['pur_by_points'][] = $pur_by_point_arr;
							} else {
								$pur_by_point_arr                 = array();
								$pur_by_point_arr                 = array(
									'pur_by_points' => $deduct_point,
									'date'          => $today_date,
								);
								$pur_by_points['pur_by_points'][] = $pur_by_point_arr;
							}
							update_user_meta( $user_id, 'mwb_wpr_points', $total_points );
							update_user_meta( $user_id, 'points_details', $pur_by_points );
							if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
								$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
								$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_pro_pur_by_points_email_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_pro_pur_by_points_email_subject'] : '';
								$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_pro_pur_by_points_discription_custom_id'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_pro_pur_by_points_discription_custom_id'] : '';
								$mwb_wpr_email_discription  = str_replace( '[PROPURPOINTS]', $deduct_point, $mwb_wpr_email_discription );
								$mwb_wpr_email_discription  = str_replace( '[TOTALPOINTS]', $total_points, $mwb_wpr_email_discription );
								$user                       = get_user_by( 'email', $user_email );
								$user_name                  = $user->user_firstname;
								$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
								if ( $mwb_wpr_notificatin_enable ) {
									$headers = array( 'Content-Type: text/html; charset=UTF-8' );
									wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
								}
							}
						}
					}
				}
			} else {
				if ( $mwb_wpr_is_pnt_fee_applied ) {
					$fee_amount    = -( $fee_amount );
					$fee_to_point  = round( ( $mwb_wpr_purchase_points * $fee_amount ) / $mwb_wpr_product_purchase_price );
					$points_deduct = apply_filters( 'mwb_par_convert_base_price_diffrent_currency', $fee_to_point );
					$total_points  = $get_points - $points_deduct;
					if ( $total_points < 0 ) {
						$total_points = 0;
					}
					if ( isset( $pur_by_points['pur_by_points'] ) && ! empty( $pur_by_points['pur_by_points'] ) ) {
						$pur_by_point_arr                 = array(
							'pur_by_points' => $points_deduct,
							'date'          => $today_date,
						);
						$pur_by_points['pur_by_points'][] = $pur_by_point_arr;
					} else {
						$pur_by_point_arr                 = array();
						$pur_by_point_arr                 = array(
							'pur_by_points' => $points_deduct,
							'date'          => $today_date,
						);
						$pur_by_points['pur_by_points'][] = $pur_by_point_arr;
					}
					update_user_meta( $user_id, 'mwb_wpr_points', $total_points );
					update_user_meta( $user_id, 'points_details', $pur_by_points );
					// hpos.
					mwb_par_hpos_update_meta_data( $order_id, 'mwb_par_purchase_through_points_amount', $points_deduct );
					if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
						$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
						$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_pro_pur_by_points_email_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_pro_pur_by_points_email_subject'] : '';
						$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_pro_pur_by_points_discription_custom_id'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_pro_pur_by_points_discription_custom_id'] : '';
						$mwb_wpr_email_discription  = str_replace( '[PROPURPOINTS]', $points_deduct, $mwb_wpr_email_discription );
						$mwb_wpr_email_discription  = str_replace( '[TOTALPOINTS]', $total_points, $mwb_wpr_email_discription );
						$user                       = get_user_by( 'email', $user_email );
						$user_name                  = $user->user_firstname;
						$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
						if ( $mwb_wpr_notificatin_enable ) {
							$headers = array( 'Content-Type: text/html; charset=UTF-8' );
							wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
						}
					}
				}
			}

			// Add the Cart Discount amount for particular order_id along with.
			if ( isset( $order ) && ! empty( $order ) ) {
				$order_fees = $order->get_fees();
				if ( ! empty( $order_fees ) ) {
					foreach ( $order_fees as $fee_item_id => $fee_item ) {
						$fee_id     = $fee_item_id;
						$fee_name   = $fee_item->get_name();
						$fee_amount = $fee_item->get_amount();
						$fee_amount = -( $fee_amount );
						$fee_amount = apply_filters( 'mwb_par_convert_base_price_diffrent_currency', $fee_amount );
						if ( isset( $fee_name ) && ! empty( $fee_name ) && 'Cart Discount' === $fee_name ) {
							// hpos.
							mwb_par_hpos_update_meta_data( $order_id, 'mwb_cart_discount#$fee_id', $fee_amount );

							// Now deduct the fee amount from user account as the point.
							$get_points               = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
							$cart_subtotal_point_arr  = get_user_meta( $user_id, 'points_details', true );
							$mwb_wpr_cart_points_rate = get_option( 'mwb_wpr_cart_points_rate', 1 );
							$mwb_wpr_cart_price_rate  = get_option( 'mwb_wpr_cart_price_rate', 1 );
							$fee_to_point             = ceil( ( $mwb_wpr_cart_points_rate * $fee_amount ) / $mwb_wpr_cart_price_rate );
							$remaining_point          = $get_points - $fee_to_point;
							if ( $remaining_point < 0 ) {
								$remaining_point = 0;
							}
							if ( isset( $cart_subtotal_point_arr['cart_subtotal_point'] ) && ! empty( $cart_subtotal_point_arr['cart_subtotal_point'] ) ) {
								$cart_array                                       = array(
									'cart_subtotal_point' => $fee_to_point,
									'date'                => $today_date,
								);
								$cart_subtotal_point_arr['cart_subtotal_point'][] = $cart_array;
							} else {
								if ( ! is_array( $cart_subtotal_point_arr ) ) {
									$cart_subtotal_point_arr = array();
								}
								$cart_array                                       = array(
									'cart_subtotal_point' => $fee_to_point,
									'date'                => $today_date,
								);
								$cart_subtotal_point_arr['cart_subtotal_point'][] = $cart_array;
							}
							update_user_meta( $user_id, 'mwb_wpr_points', $remaining_point );
							update_user_meta( $user_id, 'points_details', $cart_subtotal_point_arr );

							/*Unset the session*/
							if ( ! empty( WC()->session->get( 'mwb_cart_points' ) ) ) {
								WC()->session->__unset( 'mwb_cart_points' );
							}
							if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
								$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
								$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_point_on_cart_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_point_on_cart_subject'] : '';
								$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_point_on_cart_desc'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_point_on_cart_desc'] : '';
								$mwb_wpr_email_discription  = str_replace( '[DEDUCTCARTPOINT]', $fee_to_point, $mwb_wpr_email_discription );
								$mwb_wpr_email_discription  = str_replace( '[TOTALPOINTS]', $remaining_point, $mwb_wpr_email_discription );
								$user                       = get_user_by( 'email', $user_email );
								$user_name                  = $user->user_firstname;
								$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
								if ( $mwb_wpr_notificatin_enable ) {
									$headers = array( 'Content-Type: text/html; charset=UTF-8' );
									wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
								}
							}
						}
					}
				}
			}
			$product_points             = 0;
			$product_purchased_pnt_only = false;
			foreach ( $order->get_items() as $item_id => $item ) {
				$mwb_wpr_items = $item->get_meta_data();
				foreach ( $mwb_wpr_items as $key => $mwb_wpr_value ) {
					if ( isset( $mwb_wpr_value->key ) && ! empty( $mwb_wpr_value->key ) && ( 'Purchased By Points' === $mwb_wpr_value->key ) ) {
						$product_points            += (int) $mwb_wpr_value->value;
						$product_purchased_pnt_only = true;
					}
				}
			}

			$pur_pro_pnt_only = get_user_meta( $user_id, 'points_details', true );
			$pur_get_points   = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
			if ( $product_purchased_pnt_only && isset( $user_id ) && $user_id > 0 ) {
				if ( $pur_get_points >= $product_points ) {

					$mwb_par_pur_only_points_done = mwb_par_hpos_get_meta_data( $order_id, 'mwb_par_pur_only_points_done', true );
					if ( empty( $mwb_par_pur_only_points_done ) ) {

						$total_points_only = $pur_get_points - $product_points;
						if ( $total_points_only < 0 ) {
							$total_points_only = 0;
						}
						if ( isset( $pur_pro_pnt_only['pur_pro_pnt_only'] ) && ! empty( $pur_pro_pnt_only['pur_pro_pnt_only'] ) ) {
							$point_only_array                       = array(
								'pur_pro_pnt_only' => $product_points,
								'date'             => $today_date,
							);
							$pur_pro_pnt_only['pur_pro_pnt_only'][] = $point_only_array;
						} else {
							if ( ! is_array( $pur_pro_pnt_only ) ) {
								$pur_pro_pnt_only = array();
							}
							$point_only_array                       = array(
								'pur_pro_pnt_only' => $product_points,
								'date'             => $today_date,
							);
							$pur_pro_pnt_only['pur_pro_pnt_only'][] = $point_only_array;
						}
						update_user_meta( $user_id, 'mwb_wpr_points', $total_points_only );
						update_user_meta( $user_id, 'points_details', $pur_pro_pnt_only );
						mwb_par_hpos_update_meta_data( $order_id, 'mwb_par_purchase_through_points_only_reward_amount', $product_points );
						mwb_par_hpos_update_meta_data( $order_id, 'mwb_par_pur_only_points_done', 'done' );
					}
				}
			}
		}

		/**
		 * Return/Deduct Points when any user makes a Refund Request
		 *
		 * @param      string $order_id       Data.
		 * @param      string $refund_id       Data.
		 * @name mwb_wpr_woocommerce_order_refunded.
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_order_refunded( $order_id, $refund_id ) {
			$order                            = wc_get_order( $order_id );
			$user_id                          = $order->get_user_id();
			$user                             = get_user_by( 'ID', $user_id );
			$user_email                       = $user->user_email;
			$mwb_wpr_notificatin_array        = get_option( 'mwb_wpr_notificatin_array', true );
			$general_settings                 = get_option( 'mwb_wpr_settings_gallery', true );
			$mwb_wpr_coupon_conversion_value  = get_option( 'mwb_wpr_coupons_gallery', array() );
			$mwb_wpr_coupon_conversion_price  = $mwb_wpr_coupon_conversion_value['mwb_wpr_coupon_conversion_price'];
			$mwb_wpr_coupon_conversion_points = $mwb_wpr_coupon_conversion_value['mwb_wpr_coupon_conversion_points'];
			$mwb_wpr_purchase_points          = ( isset( $general_settings['mwb_wpr_purchase_points'] ) && null !== $general_settings['mwb_wpr_purchase_points'] ) ? $general_settings['mwb_wpr_purchase_points'] : 1;
			$mwb_wpr_product_purchase_price   = ( isset( $general_settings['mwb_wpr_product_purchase_price'] ) && null !== $general_settings['mwb_wpr_product_purchase_price'] ) ? intval( $general_settings['mwb_wpr_product_purchase_price'] ) : 1;
			$deduction_of_points              = get_user_meta( $user_id, 'points_details', true );
			$today_date                       = date_i18n( 'Y-m-d h:i:sa' );
			$total_points                     = '';

			foreach ( $order->get_items() as $item_id => $item ) {
				$woo_ver = WC()->version;
				if ( $woo_ver < '3.0.0' ) {
					$item_quantity = $order->get_item_meta( $item_id, '_qty', true );
					if ( isset( $item['item_meta']['Points'] ) && ! empty( $item['item_meta']['Points'] ) ) {
						$is_refunded = wc_get_order_item_meta( $item_id, 'refund_points', true );
						if ( ! isset( $is_refunded ) || 'yes' !== $is_refunded ) {
							$get_points   = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
							$deduct_point = $item['item_meta']['Points'][0];
							$total_points = $get_points - $deduct_point;
							if ( isset( $deduction_of_points['deduction_of_points'] ) && ! empty( $deduction_of_points['deduction_of_points'] ) ) {

								$deduction_arr                                = array();
								$deduction_arr                                = array(
									'deduction_of_points' => $deduct_point,
									'date'                => $today_date,
								);
								$deduction_of_points['deduction_of_points'][] = $deduction_arr;
							} else {
								if ( ! is_array( $deduction_of_points ) ) {
									$deduction_of_points = array();
								}
								$deduction_arr                                = array(
									'deduction_of_points' => $deduct_point,
									'date'                => $today_date,
								);
								$deduction_of_points['deduction_of_points'][] = $deduction_arr;
							}
							update_user_meta( $user_id, 'mwb_wpr_points', $total_points );
							update_user_meta( $user_id, 'points_details', $deduction_of_points );
							wc_update_order_item_meta( $item_id, 'refund_points', 'yes', $prev_value = '' );
							if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
								$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
								$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_deduct_assigned_point_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_deduct_assigned_point_subject'] : '';
								$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_deduct_assigned_point_desciption'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_deduct_assigned_point_desciption'] : '';
								$mwb_wpr_email_discription  = str_replace( '[DEDUCTEDPOINT]', $deduct_point, $mwb_wpr_email_discription );
								$mwb_wpr_email_discription  = str_replace( '[TOTALPOINTS]', $total_points, $mwb_wpr_email_discription );
								$user                       = get_user_by( 'email', $user_email );
								$user_name                  = $user->user_firstname;
								$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
								if ( $mwb_wpr_notificatin_enable ) {
									$headers = array( 'Content-Type: text/html; charset=UTF-8' );
									wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
								}
							}
						}
					}

					if ( isset( $item['item_meta']['Purchasing Option'] ) && ! empty( $item['item_meta']['Purchasing Option'] ) ) {
						$is_refunded = wc_get_order_item_meta( $item_id, 'refund_purchased_point', true );
						if ( ! isset( $is_refunded ) || 'yes' !== $is_refunded ) {
							$get_points          = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
							$return_pur_point    = $item['item_meta']['Purchasing Option'][0];
							$total_return_points = $get_points + $return_pur_point;
							if ( isset( $deduction_of_points['return_pur_points'] ) && ! empty( $deduction_of_points['return_pur_points'] ) ) {
								$return_arr                                 = array();
								$return_arr                                 = array(
									'return_pur_points' => $return_pur_point,
									'date'              => $today_date,
								);
								$deduction_of_points['return_pur_points'][] = $return_arr;
							} else {
								if ( ! is_array( $deduction_of_points ) ) {
									$deduction_of_points = array();
								}
								$return_arr                                 = array(
									'return_pur_points' => $return_pur_point,
									'date'              => $today_date,
								);
								$deduction_of_points['return_pur_points'][] = $return_arr;
							}
							update_user_meta( $user_id, 'mwb_wpr_points', $total_return_points );
							update_user_meta( $user_id, 'points_details', $deduction_of_points );
							wc_update_order_item_meta( $item_id, 'refund_purchased_point', 'yes', $prev_value = '' );
							if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
								$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
								$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_return_pro_pur_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_return_pro_pur_subject'] : '';
								$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_return_pro_pur_description'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_return_pro_pur_description'] : '';
								$mwb_wpr_email_discription  = str_replace( '[RETURNPOINT]', $return_pur_point, $mwb_wpr_email_discription );
								$mwb_wpr_email_discription  = str_replace( '[TOTALPOINTS]', $total_return_points, $mwb_wpr_email_discription );
								$user                       = get_user_by( 'email', $user_email );
								$user_name                  = $user->user_firstname;
								$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
								if ( $mwb_wpr_notificatin_enable ) {
									$headers = array( 'Content-Type: text/html; charset=UTF-8' );
									wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
								}
							}
						}
					}
				} else {
					$item_quantity = wc_get_order_item_meta( $item_id, '_qty', true );
					$mwb_wpr_items = $item->get_meta_data();
					if ( is_array( $mwb_wpr_items ) && ! empty( $mwb_wpr_items ) ) {
						foreach ( $mwb_wpr_items as $key => $mwb_wpr_value ) {
							if ( isset( $mwb_wpr_value->key ) && ! empty( $mwb_wpr_value->key ) && ( 'Points' === $mwb_wpr_value->key ) ) {
								$is_refunded = wc_get_order_item_meta( $item_id, 'refund_points', true );
								if ( ! isset( $is_refunded ) || 'yes' !== $is_refunded ) {
									$get_points   = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
									$deduct_point = $mwb_wpr_value->value;
									$total_points = $get_points - $deduct_point;
									if ( isset( $deduction_of_points['deduction_of_points'] ) && ! empty( $deduction_of_points['deduction_of_points'] ) ) {

										$deduction_arr                                = array();
										$deduction_arr                                = array(
											'deduction_of_points' => $deduct_point,
											'date' => $today_date,
										);
										$deduction_of_points['deduction_of_points'][] = $deduction_arr;
									} else {
										$deduction_arr                                = array();
										$deduction_arr                                = array(
											'deduction_of_points' => $deduct_point,
											'date' => $today_date,
										);
										$deduction_of_points['deduction_of_points'][] = $deduction_arr;
									}
									update_user_meta( $user_id, 'mwb_wpr_points', $total_points );
									update_user_meta( $user_id, 'points_details', $deduction_of_points );
									wc_update_order_item_meta( $item_id, 'refund_points', 'yes', $prev_value = '' );
									if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
										$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
										$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_deduct_assigned_point_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_deduct_assigned_point_subject'] : '';
										$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_deduct_assigned_point_desciption'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_deduct_assigned_point_desciption'] : '';
										$mwb_wpr_email_discription  = str_replace( '[DEDUCTEDPOINT]', $deduct_point, $mwb_wpr_email_discription );
										$mwb_wpr_email_discription  = str_replace( '[TOTALPOINTS]', $total_points, $mwb_wpr_email_discription );
										$user                       = get_user_by( 'email', $user_email );
										$user_name                  = $user->user_firstname;
										$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
										if ( $mwb_wpr_notificatin_enable ) {
											$headers = array( 'Content-Type: text/html; charset=UTF-8' );
											wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
										}
									}
								}
							}
						}
					}
				}
			}

			// hpos.
			$item_conversion_id_set = mwb_par_hpos_get_meta_data( $order_id, "$order_id#item_conversion_id", false );
			$order_total            = $order->get_total();
			if ( isset( $item_conversion_id_set[0] ) && ! empty( $item_conversion_id_set[0] ) && 'set' === $item_conversion_id_set[0] ) {
				$get_points    = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
				$all_refunds   = $order->get_refunds();
				$refund_item   = $all_refunds[0];
				$refund_amount = $refund_item->get_amount();
				// hpos.
				$deduct_currency_spent = mwb_par_hpos_get_meta_data( $order_id, 'mwb_wpr_per_currency_awarded_points', true );
				$remaining_points      = $get_points - $deduct_currency_spent;
				if ( isset( $deduction_of_points['deduction_currency_spent'] ) && ! empty( $deduction_of_points['deduction_currency_spent'] ) ) {
					$currency_arr                                      = array();
					$currency_arr                                      = array(
						'deduction_currency_spent' => $deduct_currency_spent,
						'date'                     => $today_date,
					);
					$deduction_of_points['deduction_currency_spent'][] = $currency_arr;
				} else {
					$currency_arr                                      = array();
					$currency_arr                                      = array(
						'deduction_currency_spent' => $deduct_currency_spent,
						'date'                     => $today_date,
					);
					$deduction_of_points['deduction_currency_spent'][] = $currency_arr;
				}
				update_user_meta( $user_id, 'mwb_wpr_points', $remaining_points );
				update_user_meta( $user_id, 'points_details', $deduction_of_points );
				if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
					$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
					$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_deduct_per_currency_point_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_deduct_per_currency_point_subject'] : '';
					$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_deduct_per_currency_point_description'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_deduct_per_currency_point_description'] : '';
					$mwb_wpr_email_discription  = str_replace( '[DEDUCTEDPOINT]', $deduct_currency_spent, $mwb_wpr_email_discription );
					$mwb_wpr_email_discription  = str_replace( '[TOTALPOINTS]', $remaining_points, $mwb_wpr_email_discription );
					$user                       = get_user_by( 'email', $user_email );
					$user_name                  = $user->user_firstname;
					$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
					if ( $mwb_wpr_notificatin_enable ) {
						$headers = array( 'Content-Type: text/html; charset=UTF-8' );
						wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
					}
				}
			}

			// Refund amount of Point Discount.
			if ( isset( $order ) && ! empty( $order ) ) {
				// hpos.
				$is_refunded = mwb_par_hpos_get_meta_data( $order_id, 'mwb_point_discount', true );
				if ( ! isset( $is_refunded ) || 'Refunded' !== $is_refunded ) {
					$general_settings               = get_option( 'mwb_wpr_settings_gallery', true );
					$mwb_wpr_purchase_points        = ( isset( $general_settings['mwb_wpr_purchase_points'] ) && null !== $general_settings['mwb_wpr_purchase_points'] ) ? $general_settings['mwb_wpr_purchase_points'] : 1;
					$mwb_wpr_product_purchase_price = ( isset( $general_settings['mwb_wpr_product_purchase_price'] ) && null !== $general_settings['mwb_wpr_product_purchase_price'] ) ? intval( $general_settings['mwb_wpr_product_purchase_price'] ) : 1;
					$deduction_of_points            = get_user_meta( $user_id, 'points_details', true );
					$order_fees                     = $order->get_fees();
					$get_points                     = (int) get_user_meta( $user_id, 'mwb_wpr_points', true );
					if ( ! empty( $order_fees ) ) {
						foreach ( $order_fees as $fee_item_id => $fee_item ) {
							$fee_id     = $fee_item_id;
							$fee_name   = $fee_item->get_name();
							$fee_amount = $fee_item->get_amount();
							if ( isset( $fee_name ) && ! empty( $fee_name ) && 'Point Discount' === $fee_name ) {
								// hpos.
								mwb_par_hpos_update_meta_data( $order_id, 'mwb_point_discount#$fee_id', $fee_amount );
								// Now deduct the fee amount from user account as the point.
								$fee_amount   = -( $fee_amount );
								$fee_to_point = ceil( ( $mwb_wpr_purchase_points * $fee_amount ) / $mwb_wpr_product_purchase_price );
								$total_point  = $get_points + $fee_to_point;
								if ( isset( $deduction_of_points['return_pur_points'] ) && ! empty( $deduction_of_points['return_pur_points'] ) ) {
									$return_arr                                 = array(
										'return_pur_points' => $fee_to_point,
										'date' => $today_date,
									);
									$deduction_of_points['return_pur_points'][] = $return_arr;
								} else {
									if ( ! is_array( $deduction_of_points ) ) {
										$deduction_of_points = array();
									}
									$return_arr                                 = array(
										'return_pur_points' => $fee_to_point,
										'date' => $today_date,
									);
									$deduction_of_points['return_pur_points'][] = $return_arr;
								}
								update_user_meta( $user_id, 'mwb_wpr_points', $total_point );
								update_user_meta( $user_id, 'points_details', $deduction_of_points );
								// hpos.
								mwb_par_hpos_update_meta_data( $order_id, 'mwb_point_discount', 'Refunded' );
								if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
									$mwb_wpr_notificatin_enable = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
									$mwb_wpr_email_subject      = isset( $mwb_wpr_notificatin_array['mwb_wpr_return_pro_pur_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_return_pro_pur_subject'] : '';
									$mwb_wpr_email_discription  = isset( $mwb_wpr_notificatin_array['mwb_wpr_return_pro_pur_description'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_return_pro_pur_description'] : '';
									$mwb_wpr_email_discription  = str_replace( '[RETURNPOINT]', $fee_to_point, $mwb_wpr_email_discription );
									$mwb_wpr_email_discription  = str_replace( '[TOTALPOINTS]', $total_point, $mwb_wpr_email_discription );
									$user                       = get_user_by( 'email', $user_email );
									$user_name                  = $user->user_firstname;
									$mwb_wpr_email_discription  = str_replace( '[USERNAME]', $user_name, $mwb_wpr_email_discription );
									if ( $mwb_wpr_notificatin_enable ) {
										$headers = array( 'Content-Type: text/html; charset=UTF-8' );
										wc_mail( $user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
									}
								}
							}
						}
					}
				}
			}
		}

		/**
		 * Runs a cron for notifying the users who have any memberhip level and which is going to be expired in next two weeks.
		 *
		 * @name mwb_wpr_do_this_hourly.
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function mwb_wpr_do_this_hourly() {
			$today_date         = date_i18n( 'Y-m-d' );
			$args['meta_query'] = array(
				array(
					'key' => 'membership_level',
				),
			);
			$user_data          = get_users( $args );
			if ( is_array( $user_data ) && ! empty( $user_data ) ) {
				foreach ( $user_data as $key => $value ) {
					$user_id    = $value->data->ID;
					$user_email = $value->data->user_email;
					if ( isset( $user_id ) && ! empty( $user_id ) ) {
						$mwb_wpr_mem_expr = get_user_meta( $user_id, 'membership_expiration', true );
						$user_level       = get_user_meta( $user_id, 'membership_level', true );
						if ( isset( $mwb_wpr_mem_expr ) && ! empty( $mwb_wpr_mem_expr ) ) {
							$notification_date = gmdate( 'Y-m-d', strtotime( $mwb_wpr_mem_expr . ' -1 weeks' ) );
							if ( $today_date == $notification_date ) {
								$subject = __( 'Membership Expiration Alert!', 'woocommerce-ultimate-points-and-rewards' );
								$message = __( 'Your User Level ', 'woocommerce-ultimate-points-and-rewards' ) . $user_level . __( ' is going to expire on the date of ', 'woocommerce-ultimate-points-and-rewards' ) . $mwb_wpr_mem_expr . __( ' You can upgrade your level or can renew that level again after expiration.', 'woocommerce-ultimate-points-and-rewards' );
								wc_mail( $user_email, $subject, $message );
							}
							$expired_date = gmdate( 'Y-m-d', strtotime( $mwb_wpr_mem_expr ) );
							if ( $today_date >= $expired_date && ! empty( $user_level ) ) {
								delete_user_meta( $user_id, 'membership_level' );
								$subject = __( 'No Longer Membership User', 'woocommerce-ultimate-points-and-rewards' );
								$message = __( 'Your User Level ', 'woocommerce-ultimate-points-and-rewards' ) . $user_level . __( ' has been expired. You can upgrade your level to another or can renew that level again ', 'woocommerce-ultimate-points-and-rewards' );
								wc_mail( $user_email, $subject, $message );
							}
						}
					}
				}
			}
		}

		/**
		 * This function is used to add the Custom Widget for Points and Reward
		 *
		 * @name mwb_wpr_custom_widgets.
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function mwb_wpr_custom_widgets() {
			include_once MWB_WPR_DIRPATH . '/includes/admin/class-mwb-wpr-custom-widget.php';
		}

		/**
		 * This function is used to add the Points inside the Orders(if any)
		 *
		 * @param      object $order       Data.
		 * @name mwb_wpr_woocommerce_admin_order_item_headers.
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_admin_order_item_headers( $order ) {

			foreach ( $order->get_items() as $item_id => $item ) {
				$woo_ver = WC()->version;
				if ( $woo_ver < '3.0.0' ) {
					if ( isset( $item['item_meta']['Points'] ) && ! empty( $item['item_meta']['Points'] ) ) {
						?>
						<th class="quantity sortable"><?php esc_html_e( 'Points', 'woocommerce-ultimate-points-and-rewards' ); ?></th>
						<?php
					}
				} else {
					$mwb_wpr_items = $item->get_meta_data();
					foreach ( $mwb_wpr_items as $key => $mwb_wpr_value ) {
						if ( isset( $mwb_wpr_value->key ) && ! empty( $mwb_wpr_value->key ) && ( 'Points' === $mwb_wpr_value->key ) ) {
							?>
							<th class="quantity sortable"><?php esc_html_e( 'Points', 'woocommerce-ultimate-points-and-rewards' ); ?></th>
							<?php
						}
					}
				}
			}
		}

		/**
		 * This function is used to add the Points inside the Orders(if any)
		 *
		 * @param      string $product       Data.
		 * @param      object $item       Data.
		 * @param      string $item_id       Data.
		 * @name mwb_wpr_woocommerce_admin_order_item_values.
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_admin_order_item_values( $product, $item, $item_id ) {
			$woo_ver = WC()->version;
			if ( $woo_ver < '3.0.0' ) {
				if ( isset( $item['item_meta']['Points'] ) && ! empty( $item['item_meta']['Points'] ) ) {
					$item_points = (int) $item['item_meta']['Points'][0];
					?>
					<td class="item_cost" width="1%" data-sort-value="<?php echo esc_attr( $item_points ); ?>">
					<div class="view">
						<?php
							echo esc_attr( $item_points );
						?>
					</div>
				</td>
					<?php
				}
			} else {
				$mwb_wpr_items = $item->get_meta_data();
				foreach ( $mwb_wpr_items as $key => $mwb_wpr_value ) {
					if ( isset( $mwb_wpr_value->key ) && ! empty( $mwb_wpr_value->key ) && ( 'Points' === $mwb_wpr_value->key ) ) {
						$item_points = (int) $mwb_wpr_value->value;
						?>
						<td class="item_cost" width="1%" data-sort-value="<?php echo esc_attr( $item_points ); ?>">
							<div class="view">
								<?php
								echo esc_attr( $item_points );
								?>
							</div>
						</td>
						<?php
					}
				}
			}
		}

		/**
		 * This function is used to add the textbox for variable products
		 *
		 * @param      string $loop       Data.
		 * @param      string $variation_data       Data.
		 * @param      object $variation       Data.
		 * @name mwb_wpr_woocommerce_variation_options_pricing
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_variation_options_pricing( $loop, $variation_data, $variation ) {
			$woo_ver = WC()->version;
			if ( $woo_ver < '3.0.0' ) {
				$mwb_wpr_variable_points = get_post_meta( $variation->ID, 'mwb_wpr_variable_points', true );
			} else {
				if ( isset( $variation_data['mwb_wpr_variable_points'][0] ) ) {
					$mwb_wpr_variable_points = $variation_data['mwb_wpr_variable_points'][0];
				} else {
					$mwb_wpr_variable_points = '';
				}
			}

			?>
			<?php
			if ( is_admin() ) {
					woocommerce_wp_text_input(
						array(
							'id'            => "mwb_wpr_variable_points_{$loop}",
							'name'          => "mwb_wpr_variable_points_{$loop}",
							'value'         => $mwb_wpr_variable_points,
							'label'         => __( 'Enter Point', 'woocommerce-ultimate-points-and-rewards' ),
							'data_type'     => 'price',
							'wrapper_class' => 'form-row form-row-first',
							'placeholder'   => __( 'Product Point', 'woocommerce-ultimate-points-and-rewards' ),
						)
					);
			}
			// MWB Custom Work.

			if ( isset( $variation_data['mwb_wpr_variable_points_purchase'][0] ) ) {
				$mwb_wpr_variable_points_purchase = $variation_data['mwb_wpr_variable_points_purchase'][0];
			} else {
				$mwb_wpr_variable_points_purchase = '';
			}

			if ( is_admin() ) {
					woocommerce_wp_text_input(
						array(
							'id'            => "mwb_wpr_variable_points_purchase_{$loop}",
							'name'          => "mwb_wpr_variable_points_purchase_{$loop}",
							'value'         => $mwb_wpr_variable_points_purchase,
							'label'         => __( 'Enter Point for purchase', 'woocommerce-ultimate-points-and-rewards' ),
							'data_type'     => 'price',
							'wrapper_class' => 'form-row form-row-first',
							'placeholder'   => __( 'Product Point for purchase', 'woocommerce-ultimate-points-and-rewards' ),
						)
					);
			}
			?>
			<input type="hidden" name="mwb_variable_product_hidden_field"></input>
			<?php $nonce = wp_create_nonce( 'mwb-wpr-admin-action' ); ?>
			<input type="hidden" name="mwb_wpr_variable_product_nonce_verify" value="<?php echo esc_attr( $nonce ); ?>" />
			<?php
			// End Of Custom Work.
		}

		/**
		 * This function is used to save the product variation points
		 *
		 * @param      string $variation_id       Data.
		 * @param      string $i       Data.
		 * @name mwb_wpr_woocommerce_save_product_variation
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function mwb_wpr_woocommerce_save_product_variation( $variation_id, $i ) {
			$mwb_wpr_variable_product_nonce_verify = ! empty( $_POST['mwb_wpr_variable_product_nonce_verify'] ) ? sanitize_text_field( wp_unslash( $_POST['mwb_wpr_variable_product_nonce_verify'] ) ) : '';
			if ( wp_verify_nonce( $mwb_wpr_variable_product_nonce_verify, 'mwb-wpr-admin-action' ) ) {
				if ( isset( $_POST['mwb_variable_product_hidden_field'] ) ) {
					if ( isset( $_POST[ 'mwb_wpr_variable_points_' . $i ] ) ) {
						$mwb_wpr_points = isset( $_POST[ 'mwb_wpr_variable_points_' . $i ] ) ? sanitize_text_field( wp_unslash( $_POST[ 'mwb_wpr_variable_points_' . $i ] ) ) : ''; // phpcs:ignore
						update_post_meta( $variation_id, 'mwb_wpr_variable_points', $mwb_wpr_points );
					}
					if ( isset( $_POST[ 'mwb_wpr_variable_points_purchase_' . $i ] ) ) {
						$mwb_wpr_points_purchase = isset( $_POST[ 'mwb_wpr_variable_points_purchase_' . $i ] ) ? sanitize_text_field( wp_unslash( $_POST[ 'mwb_wpr_variable_points_purchase_' . $i ] ) ) : '';// phpcs:ignore.
						update_post_meta( $variation_id, 'mwb_wpr_variable_points_purchase', $mwb_wpr_points_purchase );
					}
				}
			}
		}

		/**
		 * This function is used for run the cron for points expiration and handles accordingly
		 *
		 * @name mwb_wpr_check_daily_about_points_expiration
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function mwb_wpr_check_daily_about_points_expiration() {
			$message                          = '';
			$mwb_wpr_points_expiration_enable = get_option( 'mwb_wpr_points_expiration_enable', 'off' );
			$mwb_wpr_email_tpl                = file_get_contents( MWB_WPR_DIRPATH . '/includes/admin/mwb-wpr-points-expiration-email-template.php' );
			$mwb_wpr_points_expiration_email  = get_option( 'mwb_wpr_points_expiration_email', '' );
			if ( 'on' === $mwb_wpr_points_expiration_enable ) {
				$mwb_wpr_points_expiration_threshold = get_option( 'mwb_wpr_points_expiration_threshold', '' );
				$mwb_wpr_points_expiration_time_num  = get_option( 'mwb_wpr_points_expiration_time_num', '' );
				$mwb_wpr_points_expiration_time_drop = get_option( 'mwb_wpr_points_expiration_time_drop', 'days' );
				$today_date                          = date_i18n( 'Y-m-d' );
				$args['meta_query']                  = array(
					array(
						'key' => 'mwb_wpr_points',
					),
				);
				$user_data                           = get_users( $args );
				if ( is_array( $user_data ) && ! empty( $user_data ) ) {
					foreach ( $user_data as $key => $value ) {
						$user_id    = $value->data->ID;
						$user_email = $value->data->user_email;

						if ( isset( $user_id ) && ! empty( $user_id ) ) {
							$get_points = get_user_meta( $user_id, 'mwb_wpr_points', true );

							if ( $get_points == $mwb_wpr_points_expiration_threshold || $get_points > $mwb_wpr_points_expiration_threshold ) {
								$get_expiration_date = get_user_meta( $user_id, 'mwb_wpr_points_expiration_date', true );

								if ( ! isset( $get_expiration_date ) || empty( $get_expiration_date ) ) {
									$expiration_date = date_i18n( 'Y-m-d', strtotime( $today_date . ' +' . $mwb_wpr_points_expiration_time_num . ' ' . $mwb_wpr_points_expiration_time_drop ) );

									update_user_meta( $user_id, 'mwb_wpr_points_expiration_date', $expiration_date );
									$headers = array( 'Content-Type: text/html; charset=UTF-8' );
									// Expiration Date has been set to User.
									$subject                 = __( 'Redeem your Points before it will get expired!', 'woocommerce-ultimate-points-and-rewards' );
									$mwb_wpr_threshold_notif = get_option( 'mwb_wpr_threshold_notif', 'You have reached your Threshold and your Total Point is: [TOTALPOINT], which will get expired on [EXPIRYDATE]' );
									$message                 = $mwb_wpr_email_tpl;
									$message                 = str_replace( '[CUSTOMMESSAGE]', $mwb_wpr_threshold_notif, $message );
									$sitename                = get_bloginfo();
									$message                 = str_replace( '[SITENAME]', $sitename, $message );
									$message                 = str_replace( '[TOTALPOINT]', $get_points, $message );
									$message                 = str_replace( '[EXPIRYDATE]', $expiration_date, $message );
									wc_mail( $user_email, $subject, $message, $headers );
								}
							}

							$get_expiration_date = get_user_meta( $user_id, 'mwb_wpr_points_expiration_date', true );
							if ( isset( $get_expiration_date ) && ! empty( $get_expiration_date ) ) {
								$send_notification_date = date_i18n( 'Y-m-d', strtotime( $get_expiration_date . ' -' . $mwb_wpr_points_expiration_email . ' days' ) );
								if ( isset( $send_notification_date ) && ! empty( $send_notification_date ) ) {
									if ( $today_date == $send_notification_date ) {

										if ( get_transient( 'wps_wpr_send_notify_mail_' . $user_id ) ) {
											return;
										}
										if ( ! headers_sent() && did_action( 'wp_loaded' ) ) {
											set_transient( 'wps_wpr_send_notify_mail_' . $user_id, true, DAY_IN_SECONDS );
										}

										$mwb_user_point_expiry   = get_user_meta( $user_id, 'mwb_wpr_points_expiration_date', true );
										$headers                 = array( 'Content-Type: text/html; charset=UTF-8' );
										$subject                 = __( 'Hurry!! Points Expiration has just a few days', 'woocommerce-ultimate-points-and-rewards' );
										$mwb_wpr_re_notification = get_option( 'mwb_wpr_re_notification', 'Do not forget to redeem your points([TOTALPOINT]) before it will get expired on [EXPIRYDATE]' );
										$message                 = $mwb_wpr_email_tpl;
										$message                 = str_replace( '[CUSTOMMESSAGE]', $mwb_wpr_re_notification, $message );
										$sitename                = get_bloginfo();
										$message                 = str_replace( '[SITENAME]', $sitename, $message );
										$message                 = str_replace( '[TOTALPOINT]', $get_points, $message );
										$message                 = str_replace( '[EXPIRYDATE]', $mwb_user_point_expiry, $message );
										// expiration email before one week.
										wc_mail( $user_email, $subject, $message, $headers );
									}
								}

								if ( $today_date == $get_expiration_date && $get_points > 0 ) {

									if ( get_transient( 'wps_wpr_par_point_expire_' . $user_id ) ) {
										return;
									}
									if ( ! headers_sent() && did_action( 'wp_loaded' ) ) {
										set_transient( 'wps_wpr_par_point_expire_' . $user_id, true, DAY_IN_SECONDS );
									}

									$expired_detail_points = get_user_meta( $user_id, 'points_details', true );
									if ( isset( $expired_detail_points['expired_details'] ) && ! empty( $expired_detail_points['expired_details'] ) ) {

										$exp_array                                  = array(
											'expired_details' => $get_points,
											'date' => $today_date,
										);
										$expired_detail_points['expired_details'][] = $exp_array;
									} else {
										if ( ! is_array( $expired_detail_points ) ) {
											$expired_detail_points = array();
										}
										$exp_array                                  = array(
											'expired_details' => $get_points,
											'date' => $today_date,
										);
										$expired_detail_points['expired_details'][] = $exp_array;
									}
									update_user_meta( $user_id, 'mwb_wpr_points', 0 );
									update_user_meta( $user_id, 'points_details', $expired_detail_points );
									delete_user_meta( $user_id, 'mwb_wpr_points_expiration_date' );
									$headers                      = array( 'Content-Type: text/html; charset=UTF-8' );
									$subject                      = __( 'Points has been Expired!', 'woocommerce-ultimate-points-and-rewards' );
									$mwb_wpr_expired_notification = get_option( 'mwb_wpr_expired_notification', 'Your Points has been expired, you may earn more Points and use the benefit more' );
									$message                      = $mwb_wpr_email_tpl;
									$sitename                     = get_bloginfo();
									$message                      = str_replace( '[SITENAME]', $sitename, $message );
									$message                      = str_replace( '[CUSTOMMESSAGE]', $mwb_wpr_expired_notification, $message );
									// points has been expired.
									wc_mail( $user_email, $subject, $message, $headers );
								}
							}
						}
					}
				}
			}
		}

		/**
		 * This function is used for verifying the licensing code
		 *
		 * @name mwb_wpr_register_license
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link https://www.makewebbetter.com/
		 */
		public function mwb_wpr_register_license() {
			check_ajax_referer( 'mwb-wpr-verify-nonce', 'mwb_nonce' );

			// Remove the www from the Host Name.
			$host_server = isset( $_SERVER['HTTP_HOST'] ) ? sanitize_text_field( wp_unslash( $_SERVER['HTTP_HOST'] ) ) : '';
			if ( strpos( $host_server, 'www.' ) == 0 ) {

				$host_server = str_replace( 'www.', '', $host_server );
			}

			$mwb_license_key   = isset( $_POST['license_key'] ) ? sanitize_text_field( wp_unslash( $_POST['license_key'] ) ) : '';
			$mwb_admin_name    = '';
			$mwb_admin_email   = get_option( 'admin_email', null );
			$mwb_admin_details = get_user_by( 'email', $mwb_admin_email );
			if ( isset( $mwb_admin_details->data ) ) {
				if ( isset( $mwb_admin_details->data->display_name ) ) {
					$mwb_admin_name = $mwb_admin_details->data->display_name;
				}
			}

			$mwb_license_arr       = array(
				'license_key' => $mwb_license_key,
				'domain_name' => $host_server,
				'admin_name'  => $mwb_admin_name,
				'admin_email' => $mwb_admin_email,
				'plugin_name' => 'WooCommerce Ultimate Points And Rewards',
			);
			$postdata['body']      = $mwb_license_arr;
			$postdata['sslverify'] = false;
			$response              = wp_remote_post( 'https://wpswings.com/codecanyon/validate_license.php', $postdata );

			$mwb_res               = array();
			if ( isset( $response['body'] ) ) {
				$mwb_res = $response['body'];
				$mwb_res = json_decode( $mwb_res, true );
			}
			if ( isset( $mwb_res['status'] ) ) {
				if ( true === $mwb_res['status'] ) {
					update_option( 'mwb_wpr_license_hash', $mwb_res['hash'] );
					update_option( 'mwb_wpr_plugin_name', 'WooCommerce Ultimate Points And Rewards' );
					update_option( 'mwb_wpr_license_key', $mwb_res['mwb_key'] );
					update_option( 'mwb_wpr_plugin_verified', true );
					echo json_encode(
						array(
							'status' => true,
							'msg'    => __(
								'Successfully Verified',
								'woocommerce-ultimate-points-and-rewards'
							),
						)
					);
				} elseif ( false === $mwb_res['status'] ) {
					update_option( 'mwb_wpr_plugin_verified', false );
					echo json_encode(
						array(
							'status' => false,
							'msg'    => $mwb_res['msg'],
						)
					);
				}
			} else {
				echo json_encode(
					array(
						'status' => false,
						'msg'    => 'Please Try Again!',
					)
				);
			}
			wp_die();
		}

		/**
		 * This function is used to show link on plugin listing page.
		 *
		 * @param string $links links.
		 * @param string $file file.
		 * @return string
		 */
		public function mwb_wpr_custom_plugin_codecanyon( $links, $file ) {
			if ( strpos( $file, 'woocommerce-ultimate-points-and-rewards/woocommerce-ultimate-points-and-rewards.php' ) !== false ) {
				$new_links = array(
					'demo'     => '<a href="https://demo.wpswings.com/woocommerce-ultimate-points-and-rewards/my-account/?utm_source=wpswings-par-demo&utm_medium=par-cc-backend&utm_campaign=demo" target="_blank"><img src="' . esc_html( MWB_WPR_URL ) . 'assets/images/Demo.svg" class="wps-info-img" alt="Demo image" style="vertical-align : middle;"><i class="far fa-file-alt" style="margin-right:3px; display: inline-block;max-width: 15px;margin-top: -3px;"></i>' . esc_html__( 'Demo', 'woocommerce-ultimate-points-and-rewards' ) . '</a>',
					'doc'      => '<a href="https://docs.wpswings.com/woocommerce-ultimate-points-and-rewards/?utm_source=wpswings-par-doc&utm_medium=par-cc-backend&utm_campaign=doc" target="_blank"><img src="' . esc_html( MWB_WPR_URL ) . 'assets/images/Documentation.svg" class="wps-info-img" alt="Demo image" style="vertical-align : middle;"><i class="far fa-file-alt" style="margin-right:3px;display: inline-block;max-width: 15px;margin-top: -3px;"></i>' . esc_html__( 'Documentation', 'woocommerce-ultimate-points-and-rewards' ) . '</a>',
					'video'    => '<a href="https://www.youtube.com/watch?v=G-8SUDcXn4g" target="_blank"><img src="' . esc_html( MWB_WPR_URL ) . 'assets/images/wps-youtube.svg" class="wps-info-img" alt="Demo image" style="vertical-align : middle;width: 18px;"><i class="fas fa-user-ninja" style="margin-right:3px;display: inline-block;max-width: 15px;margin-top: -3px;"></i>' . esc_html__( 'Video', 'woocommerce-ultimate-points-and-rewards' ) . '</a>',
					'support'  => '<a href="https://wpswings.com/submit-query/?utm_source=wpswings-par-support&utm_medium=par-cc-backend&utm_campaign=support" target="_blank"><img src="' . esc_html( MWB_WPR_URL ) . 'assets/images/Support.svg" class="wps-info-img" alt="Demo image" style="vertical-align : middle;"><i class="fas fa-user-ninja" style="margin-right:3px;display: inline-block;max-width: 15px;margin-top: -3px;"></i>' . esc_html__( 'Support', 'woocommerce-ultimate-points-and-rewards' ) . '</a>',
					'services' => '<a href="https://wpswings.com/woocommerce-services/?utm_source=wpswings-par-services&utm_medium=par-cc-backend&utm_campaign=woocommerce-services" target="_blank"><img src="' . esc_html( MWB_WPR_URL ) . 'assets/images/Services.svg" class="wps-info-img" alt="Demo image" style="max-width:22px;vertical-align : middle;"><i class="fas fa-user-ninja" style="margin-right:3px;display: inline-block;max-width: 15px;margin-top: -3px;"></i>' . esc_html__( 'Services', 'woocommerce-ultimate-points-and-rewards' ) . '</a>',
				);
				$links = array_merge( $links, $new_links );
			}
			return $links;
		}

		/**
		 * Activation of a new site.
		 *
		 * @param object $new_site Array return.
		 */
		public function par_standard_plugin_on_create_new_blog( $new_site ) {
			if ( ! function_exists( 'is_plugin_active_for_network' ) ) {
				require_once ABSPATH . '/wp-admin/includes/plugin.php';
			}
			$mwb_par_lcns_key        = get_option( 'mwb_wpr_license_key' );
			$mwb_par_lcns_hash       = get_option( 'mwb_wpr_license_hash' );
			$mwb_par_plugin_name     = get_option( 'mwb_wpr_plugin_name' );
			$mwb_par_plugin_verified = get_option( 'mwb_wpr_plugin_verified' );
			$mwb_wpr_currenttime     = get_option( 'mwb_wpr_activation_date_time' );
			// Check if the plugin has been activated on the network.
			if ( is_plugin_active_for_network( 'woocommerce-ultimate-points-and-rewards/woocommerce-ultimate-points-and-rewards.php' ) ) {

				$blog_id = $new_site->blog_id;

				switch_to_blog( $blog_id );

				update_option( 'mwb_wpr_license_hash', $mwb_par_lcns_hash );
				update_option( 'mwb_wpr_plugin_name', $mwb_par_plugin_name );
				update_option( 'mwb_wpr_license_key', $mwb_par_lcns_key );
				update_option( 'mwb_wpr_plugin_verified', $mwb_par_plugin_verified );
				update_option( 'mwb_wpr_activation_date_time', $mwb_wpr_currenttime );
				restore_current_blog();
			}
		}

		/**
		 * This function is used to add column in WP User Table.
		 *
		 * @param array $columns columns.
		 * @return array
		 */
		public function mwb_wpr_add_column( $columns ) {
			// Get general settings.
			$mwb_wpr_settings_gallery       = get_option( 'mwb_wpr_settings_gallery', array() );
			$mwb_wpr_settings_gallery       = ! empty( $mwb_wpr_settings_gallery ) && is_array( $mwb_wpr_settings_gallery ) ? $mwb_wpr_settings_gallery : array();
			$mwb_wpr_show_points_user_table = ! empty( $mwb_wpr_settings_gallery['mwb_wpr_show_points_user_table'] ) ? $mwb_wpr_settings_gallery['mwb_wpr_show_points_user_table'] : 'off';

			// check whether show user points settign enable or not.
			if ( 'on' === $mwb_wpr_show_points_user_table ) {

				$name  = $columns['name'];
				$email = $columns['email'];
				$role  = $columns['role'];
				$post  = $columns['posts'];

				unset( $columns['name'] );
				unset( $columns['email'] );
				unset( $columns['role'] );
				unset( $columns['posts'] );

				$columns['name']        = $name;
				$columns['email']       = $email;
				$columns['user_points'] = esc_html__( 'Points', 'woocommerce-ultimate-points-and-rewards' );
				$columns['role']        = $role;
				$columns['posts']       = $post;
			}
			return $columns;
		}

		/**
		 * Adds Content To The Custom Added Column.
		 *
		 * @param string $value value.
		 * @param string $column_name column_name.
		 * @param int    $user_id user_id.
		 * @return string
		 */
		public function mwb_wpr_column_content( $value, $column_name, $user_id ) {
			// Get general settings.
			$mwb_wpr_settings_gallery       = get_option( 'mwb_wpr_settings_gallery', array() );
			$mwb_wpr_settings_gallery       = ! empty( $mwb_wpr_settings_gallery ) && is_array( $mwb_wpr_settings_gallery ) ? $mwb_wpr_settings_gallery : array();
			$mwb_wpr_show_points_user_table = ! empty( $mwb_wpr_settings_gallery['mwb_wpr_show_points_user_table'] ) ? $mwb_wpr_settings_gallery['mwb_wpr_show_points_user_table'] : 'off';

			// check whether show user points settign enable or not.
			if ( 'on' === $mwb_wpr_show_points_user_table ) {
				$wps_user_points = get_user_meta( $user_id, 'mwb_wpr_points', true );
				$wps_user_points = ! empty( $wps_user_points ) && ! is_null( $wps_user_points ) ? $wps_user_points : 0;

				// check custom field and return points.
				if ( 'user_points' === $column_name ) {
					return $wps_user_points;
				}
			}
			return $value;
		}

		/**
		 * This function is used to Preview csv file data before importing csv file.
		 *
		 * @return void
		 */
		public function mwb_wpr_preview_csv_data_action_callback() {
			check_ajax_referer( 'mwb-wpr-verify-nonce', 'mwb_nonce' );
			if ( isset( $_POST ) ) {

				WP_Filesystem();
				global $wp_filesystem;

				$temp_file_path = ! empty( $_FILES['userpoints_csv_import']['tmp_name'] ) ? sanitize_text_field( wp_unslash( $_FILES['userpoints_csv_import']['tmp_name'] ) ) : '';
				$file_path      = ! empty( $_FILES['userpoints_csv_import']['name'] ) ? sanitize_text_field( wp_unslash( $_FILES['userpoints_csv_import']['name'] ) ) : '';

				// if path is empty then return from here.
				if ( empty( pathinfo( $file_path, PATHINFO_EXTENSION ) ) ) {
					wp_send_json(
						array(
							'result' => false,
							'msg'    => 'Please choose file',
						)
					);
					wp_die();
				}

				// check if file extension is not csv then return from here.
				if ( ( pathinfo( $file_path, PATHINFO_EXTENSION ) != 'csv' ) ) {
					wp_send_json(
						array(
							'result' => 'undefined',
							'msg'    => 'Please choose csv format',
						)
					);
					wp_die();
				}

				// get data from csv file and send in html format.
				$row = 1;
				if ( fopen( $temp_file_path, 'r' ) ) {
					$handle = fopen( $temp_file_path, 'r' );

					echo '<table>';
					while ( false !== ( $data = fgetcsv( $handle, 1000, ',' ) ) ) {
						$num = count( $data );
						$row++;

						echo '<tr>';
						for ( $c = 0; $c < $num; $c++ ) {
							echo '<td>' . wp_kses_post( $data[ $c ] ) . '</td>';
						}
						echo '</tr>';
					}
					echo '</table>';

					fclose( $handle );
				}
			}
			wp_die();
		}

		/**
		 * This function is used to rewards points when subscription order is renewal.
		 *
		 * @param string $order_id order_id.
		 * @return void
		 */
		public function mwb_wpr_rewards_subcription_renewal_points( $order_id ) {

			if ( ! empty( $order_id ) ) {

				// subscription compatible settings.
				$mwb_wpr_settings_gallery     = get_option( 'mwb_wpr_settings_gallery', array() );
				$mwb_wpr_settings_gallery     = ! empty( $mwb_wpr_settings_gallery ) && is_array( $mwb_wpr_settings_gallery ) ? $mwb_wpr_settings_gallery : array();
				$mwb_wpr_enable_subs_settings = ! empty( $mwb_wpr_settings_gallery['mwb_wpr_enable_subs_settings'] ) ? $mwb_wpr_settings_gallery['mwb_wpr_enable_subs_settings'] : 'off';
				$mwb_wpr_subs_renewal_points  = ! empty( $mwb_wpr_settings_gallery['mwb_wpr_subs_renewal_points'] ) ? $mwb_wpr_settings_gallery['mwb_wpr_subs_renewal_points'] : '1';
				$mwb_wpr_show_renewal_notice  = ! empty( $mwb_wpr_settings_gallery['mwb_wpr_show_renewal_notice'] ) ? $mwb_wpr_settings_gallery['mwb_wpr_show_renewal_notice'] : 'off';
				$mwb_wpr_renewal_notice       = ! empty( $mwb_wpr_settings_gallery['mwb_wpr_renewal_notice'] ) ? $mwb_wpr_settings_gallery['mwb_wpr_renewal_notice'] : '';

				if ( 'on' === $mwb_wpr_enable_subs_settings ) {

					$order              = wc_get_order( $order_id );
					$user_id            = absint( $order->get_user_id() );
					$user               = get_user_by( 'ID', $user_id );
					$user_email         = $user->user_email;
					$user_name          = $user->user_login;
					$today_date         = date_i18n( 'Y-m-d h:i:sa' );
					$mwb_wpr_points     = get_user_meta( $user_id, 'mwb_wpr_points', true );
					$mwb_wpr_points     = ! empty( $mwb_wpr_points ) && ! is_null( $mwb_wpr_points ) ? $mwb_wpr_points : 0;
					$mwb_points_details = get_user_meta( $user_id, 'points_details', true );
					$mwb_points_details = ! empty( $mwb_points_details ) && is_array( $mwb_points_details ) ? $mwb_points_details : array();

					$mwb_wpr_renewal_points_awarded_done = mwb_par_hpos_get_meta_data( $order_id, 'mwb_wpr_renewal_points_awarded_done', true );
					if ( empty( $mwb_wpr_renewal_points_awarded_done ) ) {
						if ( 'processing' === $order->get_status() ) {

							$mwb_wpr_email_custom_template = file_get_contents( MWB_WPR_DIRPATH . '/includes/admin/mwb-wpr-points-expiration-email-template.php' );
							$updated_points                = $mwb_wpr_points + $mwb_wpr_subs_renewal_points;

							if ( isset( $mwb_points_details['subscription_renewal_rewards_points'] ) && ! empty( $mwb_points_details['subscription_renewal_rewards_points'] ) ) {

								$currency_arr = array();
								$currency_arr = array(
									'subscription_renewal_rewards_points' => $mwb_wpr_subs_renewal_points,
									'date'                        => $today_date,
								);
								$mwb_points_details['subscription_renewal_rewards_points'][] = $currency_arr;
							} else {
								$currency_arr = array();
								$currency_arr = array(
									'subscription_renewal_rewards_points' => $mwb_wpr_subs_renewal_points,
									'date'                        => $today_date,
								);
								$mwb_points_details['subscription_renewal_rewards_points'][] = $currency_arr;
							}

							update_user_meta( $user_id, 'mwb_wpr_points', $updated_points );
							update_user_meta( $user_id, 'points_details', $mwb_points_details );

							mwb_par_hpos_update_meta_data( $order_id, 'mwb_wpr_renewal_points_awarded_done', 'done' );
							mwb_par_hpos_update_meta_data( $order_id, 'mwb_wpr_subs_renewal_rewarded_points', $mwb_wpr_subs_renewal_points );

							$headers                  = array( 'Content-Type: text/html; charset=UTF-8' );
							$subject                  = esc_html__( 'Subscription Renewal Points Added!', 'woocommerce-ultimate-points-and-rewards' );
							$mwb_wpr_subs_renewal_msg = esc_html__( 'You have earned points towards subscription product renewals.', 'woocommerce-ultimate-points-and-rewards' );
							$message                  = $mwb_wpr_email_custom_template;
							$sitename                 = get_bloginfo();
							$message                  = str_replace( '[SITENAME]', $sitename, $message );
							$message                  = str_replace( '[CUSTOMMESSAGE]', $mwb_wpr_subs_renewal_msg, $message );
							wc_mail( $user_email, $subject, $message, $headers );
						}
					}
				}
			}
		}

		/**
		 * This function is used manage points when subscription renewal order is refund/cancel.
		 *
		 * @param  string $order_id   order id.
		 * @param  string $old_status old status.
		 * @param  string $new_status new status.
		 * @return bool
		 */
		public function mwb_wpr_deduct_subs_renewal_points( $order_id, $old_status, $new_status ) {

			if ( $old_status != $new_status ) {

				$order      = wc_get_order( $order_id );
				$user_id    = $order->get_user_id();
				$today_date = date_i18n( 'Y-m-d h:i:sa' );
				if ( empty( $user_id ) ) {

					return false;
				}
				if ( is_plugin_active( 'subscriptions-for-woocommerce/subscriptions-for-woocommerce.php' ) ) {

					$users_points    = ! empty( get_user_meta( $user_id, 'mwb_wpr_points', true ) ) ? get_user_meta( $user_id, 'mwb_wpr_points', true ) : 0;
					$subs_refund_log = get_user_meta( $user_id, 'points_details', true );
					$subs_refund_log = ! empty( $subs_refund_log ) && is_array( $subs_refund_log ) ? $subs_refund_log : array();
					$mwb_wpr_array   = array( 'processing', 'completed' );

					if ( in_array( $old_status, $mwb_wpr_array, true ) && ( 'cancelled' === $new_status || 'refunded' === $new_status ) ) {
						if ( array_key_exists( 'subscription_renewal_rewards_points', $subs_refund_log ) ) {

							$mwb_wpr_subs_renewal_rewarded_points = mwb_par_hpos_get_meta_data( $order_id, 'mwb_wpr_subs_renewal_rewarded_points', true );
							$mwb_wpr_subs_refunded_success        = mwb_par_hpos_get_meta_data( $order_id, 'mwb_wpr_subs_refunded_success', true );
							if ( empty( $mwb_wpr_subs_refunded_success ) ) {
								if ( $mwb_wpr_subs_renewal_rewarded_points > 0 ) {

									$updated_points = $users_points - $mwb_wpr_subs_renewal_rewarded_points;

									if ( ! empty( $subs_refund_log['refund_subs_points'] ) ) {

										$arr                                     = array();
										$arr                                     = array(
											'refund_subs_points' => $mwb_wpr_subs_renewal_rewarded_points,
											'date'               => $today_date,
										);
										$subs_refund_log['refund_subs_points'][] = $arr;
									} else {
										$arr                                     = array();
										$arr                                     = array(
											'refund_subs_points' => $mwb_wpr_subs_renewal_rewarded_points,
											'date'               => $today_date,
										);
										$subs_refund_log['refund_subs_points'][] = $arr;
									}

									update_user_meta( $user_id, 'mwb_wpr_points', $updated_points );
									update_user_meta( $user_id, 'points_details', $subs_refund_log );
									mwb_par_hpos_update_meta_data( $order_id, 'mwb_wpr_subs_refunded_success', 'done' );
								}
							}
						}
					}
				}

				$mwb_par_order_statuses = array( 'processing', 'on-hold', 'failed', 'completed' );
				if ( in_array( $old_status, $mwb_par_order_statuses, true ) && ( 'cancelled' === $new_status || 'refunded' === $new_status ) ) {

					$mwb_par_refunded_purchase_through_points_only = get_user_meta( $user_id, 'points_details', true );
					$mwb_par_refunded_purchase_through_points_only = ! empty( $mwb_par_refunded_purchase_through_points_only ) && is_array( $mwb_par_refunded_purchase_through_points_only ) ? $mwb_par_refunded_purchase_through_points_only : array();
					if ( array_key_exists( 'pur_pro_pnt_only', $mwb_par_refunded_purchase_through_points_only ) ) {

						$mwb_par_purchase_through_points_only_refunded = mwb_par_hpos_get_meta_data( $order_id, 'mwb_par_purchase_through_points_only_refunded', true );
						if ( empty( $mwb_par_purchase_through_points_only_refunded ) ) {

							$mwb_par_purchase_through_points_only_reward_amount = mwb_par_hpos_get_meta_data( $order_id, 'mwb_par_purchase_through_points_only_reward_amount', true );
							$mwb_par_purchase_through_points_only_reward_amount = ! empty( $mwb_par_purchase_through_points_only_reward_amount ) ? $mwb_par_purchase_through_points_only_reward_amount : 0;
							if ( $mwb_par_purchase_through_points_only_reward_amount > 0 ) {

								$user_get_points    = get_user_meta( $user_id, 'mwb_wpr_points', true );
								$user_get_points    = ! empty( $user_get_points ) ? $user_get_points : 0;
								$mwb_updated_points = (int) $user_get_points + $mwb_par_purchase_through_points_only_reward_amount;
								if ( isset( $mwb_par_refunded_purchase_through_points_only['purchase_through_only_refunded'] ) && ! empty( $mwb_par_refunded_purchase_through_points_only['purchase_through_only_refunded'] ) ) {

									$arr = array();
									$arr = array(
										'purchase_through_only_refunded' => $mwb_par_purchase_through_points_only_reward_amount,
										'date'                           => $today_date,
									);
									$mwb_par_refunded_purchase_through_points_only['purchase_through_only_refunded'][] = $arr;
								} else {

									$arr = array();
									$arr = array(
										'purchase_through_only_refunded' => $mwb_par_purchase_through_points_only_reward_amount,
										'date'                           => $today_date,
									);
									$mwb_par_refunded_purchase_through_points_only['purchase_through_only_refunded'][] = $arr;
								}
								update_user_meta( $user_id, 'mwb_wpr_points', $mwb_updated_points );
								update_user_meta( $user_id, 'points_details', $mwb_par_refunded_purchase_through_points_only );
								mwb_par_hpos_update_meta_data( $order_id, 'mwb_par_purchase_through_points_only_refunded', 'done' );
							}
						}
					}
				}
			}
		}
	}
	new MWB_WPR_Admin_Manager();
}
?>
