<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link  https://makewebbetter.com/
 * @since 1.0.0
 *
 * @package    Woocommerce_Ultimate_Points_And_Rewards
 * @subpackage Woocommerce_Ultimate_Points_And_Rewards/admin
 */

register_widget( 'Mwb_Wpr_Custom_Widget' );

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Woocommerce_Ultimate_Points_And_Rewards
 */
class Mwb_Wpr_Custom_Widget extends WP_Widget {

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		$widget_options = array(
			'classname'   => 'mwb_wpr_custom_widget',
			'description' => 'My Point',
		);
		parent::__construct( 'mwb_wpr_custom_widget', 'Points and Rewards', $widget_options );// phpcs:ignore.
	}

	/**
	 * Function for the Widgets.
	 *
	 * @since 1.0.0
	 *
	 * @param string $args Data.
	 * @param string $instance Data.
	 */
	public function widget( $args, $instance ) {

		$title                = apply_filters( 'widget_title', $instance['title'] );
		$mypoint              = isset( $instance['mypoint'] ) && ! empty( $instance['mypoint'] ) ? $instance['mypoint'] : __( 'Total Point:', 'woocommerce-ultimate-points-and-rewards' );
		$mycurrentlevel       = isset( $instance['mycurrentlevel'] ) && ! empty( $instance['mypoint'] ) ? $instance['mycurrentlevel'] : __( 'User Level:', 'woocommerce-ultimate-points-and-rewards' );
		$membershipexpiration = isset( $instance['membershipexpiration'] ) && ! empty( $instance['membershipexpiration'] ) ? $instance['membershipexpiration'] : __( 'Expiration Date:', 'woocommerce-ultimate-points-and-rewards' );
		$user_ID              = get_current_user_ID();

		if ( isset( $user_ID ) && ! empty( $user_ID ) ) {

			echo wp_kses_post( $args['before_widget'] );
			if ( $title ) {
				echo wp_kses_post( $args['before_title'] . $title . $args['after_title'] );
			}

			$get_points = (int) get_user_meta( $user_ID, 'mwb_wpr_points', true );
			echo '<p><strong>' . esc_attr( $mypoint ) . ' ' . esc_attr( $get_points ) . '</strong></p>';
			$user_level       = get_user_meta( $user_ID, 'membership_level', true );
			$mwb_wpr_mem_expr = get_user_meta( $user_ID, 'membership_expiration', true );

			if ( isset( $user_level ) && ! empty( $user_level ) ) {
				echo '<div><strong>' . esc_attr( $mycurrentlevel ) . ' ' . esc_attr( $user_level ) . '</strong></div>';
			}
			if ( isset( $mwb_wpr_mem_expr ) && ! empty( $mwb_wpr_mem_expr ) ) {
				echo '<div><strong>' . esc_attr( $membershipexpiration ) . ' ' . esc_attr( $mwb_wpr_mem_expr ) . '</strong></div>';
			}
			echo wp_kses_post( $args['after_widget'] );
		}
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since 1.0.0
	 * @param string $instance The plugin page slug.
	 */
	public function form( $instance ) {

		$title                = '';
		$mypoint              = '';
		$mycurrentlevel       = '';
		$membershipexpiration = '';
		if ( isset( $instance ) && null !== $instance ) {
			$title                = esc_attr( $instance['title'] );
			$mypoint              = esc_attr( $instance['mypoint'] );
			$mycurrentlevel       = esc_attr( $instance['mycurrentlevel'] );
			$membershipexpiration = esc_attr( $instance['membershipexpiration'] );
		}

		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'woocommerce-ultimate-points-and-rewards' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p> 
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'mypoint' ) ); ?>"><?php esc_html_e( 'Total Point Text:', 'woocommerce-ultimate-points-and-rewards' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'mypoint' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'mypoint' ) ); ?>" type="text" value="<?php echo esc_attr( $mypoint ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'mycurrentlevel' ) ); ?>"><?php esc_html_e( 'User Level:', 'woocommerce-ultimate-points-and-rewards' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'mycurrentlevel' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'mycurrentlevel' ) ); ?>" type="text" value="<?php echo esc_attr( $mycurrentlevel ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'membershipexpiration' ) ); ?>"><?php esc_html_e( 'Expiration Text:', 'woocommerce-ultimate-points-and-rewards' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'membershipexpiration' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'membershipexpiration' ) ); ?>" type="text" value="<?php echo esc_attr( $membershipexpiration ); ?>" />
		</p>
		<?php
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since 1.0.0
	 *
	 * @param      string $new_instance       Data.
	 * @param string $old_instance The plugin page slug.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance                         = $old_instance;
		$instance['title']                = strip_tags( $new_instance['title'] );
		$instance['mypoint']              = strip_tags( $new_instance['mypoint'] );
		$instance['mycurrentlevel']       = strip_tags( $new_instance['mycurrentlevel'] );
		$instance['membershipexpiration'] = strip_tags( $new_instance['membershipexpiration'] );
		return $instance;
	}
}
?>
