<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link  https://makewebbetter.com/
 * @since 1.0.0
 *
 * @package    Woocommerce_Ultimate_Points_And_Rewards
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}

/**
 * This is construct of class where all users point listed.
 *
 * @name Mwb_Points_Table
 * @category Class
 * @author makewebbetter<webmaster@makewebbetter.com>
 * @link https://www.makewebbetter.com/
 */
class Mwb_Points_Table extends WP_List_Table {

	/**
	 * Example_data.
	 *
	 * @var [type]
	 */
	public $example_data;

	/**
	 * Mwb_total_count.
	 *
	 * @var [type]
	 */
	public $mwb_total_count;

	/**
	 * This construct colomns in point table.
	 *
	 * @name get_columns.
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	public function get_columns() {

		$columns = array(
			'cb'             => '<input type="checkbox" />',
			'user_name'      => __( 'User Name', 'woocommerce-ultimate-points-and-rewards' ),
			'user_email'     => __( 'User Email', 'woocommerce-ultimate-points-and-rewards' ),
			'user_points'    => __( 'Total Points', 'woocommerce-ultimate-points-and-rewards' ),
			'sign'           => __( 'Choose +/-', 'woocommerce-ultimate-points-and-rewards' ),
			'add_sub_points' => __( 'Enter Points', 'woocommerce-ultimate-points-and-rewards' ),
			'reason'         => __( 'Enter Remark', 'woocommerce-ultimate-points-and-rewards' ),
			'details'        => __( 'Action', 'woocommerce-ultimate-points-and-rewards' ),
		);
		return $columns;
	}

	/**
	 * This show points table list.
	 *
	 * @param      string $item       Data.
	 * @param      string $column_name       Data.
	 * @name column_default.
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	public function column_default( $item, $column_name ) {

		switch ( $column_name ) {

			case 'user_name':
				$actions = array(
					'view_point_log'     => '<a href="' . MWB_WPR_HOME_URL . 'admin.php?page=mwb-wpr-setting&tab=mwb_wpr_points_table&user_id=' . $item['id'] . '&action=view_point_log">' . __( 'View Point Log', 'woocommerce-ultimate-points-and-rewards' ) . '</a>',
					'view_coupon_detail' => '<a href="' . MWB_WPR_HOME_URL . 'admin.php?page=mwb-wpr-setting&tab=mwb_wpr_points_table&user_id=' . $item['id'] . '&action=view">' . __( 'View Coupon Detail', 'woocommerce-ultimate-points-and-rewards' ) . '</a>',
				);
				return $item[ $column_name ] . $this->row_actions( $actions );
			case 'user_email':
				return '<b>' . $item[ $column_name ] . '</b>';
			case 'user_points':
				return '<b>' . $item[ $column_name ] . '</b>';
			case 'sign':
				$html = '<select id="mwb_sign' . $item['id'] . '" style="width:35%;"><option value="+">+</option><option value="-">-</option></select>';
				return $html;
			case 'add_sub_points':
				$html = '<input style="width:75%;" type="number" min="0" id="add_sub_points' . $item['id'] . '" value="">';
				return $html;
			case 'reason':
				$html = '<input style="width: 100%;" type="text" id="mwb_remark' . $item['id'] . '" min="0" value="">';
				return $html;
			case 'details':
				return $this->view_html( $item['id'] );

			default:
				return false;
		}
	}

	/**
	 * This construct update button on points table.
	 *
	 * @param      string $user_id       Data.
	 * @name view_html.
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	public function view_html( $user_id ) {

		echo '<a  href="javascript:void(0)" class="mwb_points_update button button-primary mwb_wpr_save_changes" data-id="' . esc_attr( $user_id ) . '">' . esc_html( 'Update', 'woocommerce-ultimate-points-and-rewards' ) . '</a>';
	}

	/**
	 * Perform admin bulk action setting for points table.
	 *
	 * @name process_bulk_action.
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	public function process_bulk_action() {
		if ( 'bulk-delete' === $this->current_action() ) {
			check_admin_referer( 'bulk-' . $this->_args['plural'] );
			if ( isset( $_POST['mpr_points_ids'] ) && ! empty( $_POST['mpr_points_ids'] ) ) { //phpcs:ignore.
				$all_id = ! empty( $_POST['mpr_points_ids'] ) ? ( is_array( $_POST['mpr_points_ids'] ) ? map_deep( wp_unslash( $_POST['mpr_points_ids'] ), 'sanitize_text_field' ) : sanitize_text_field( wp_unslash( $_POST['mpr_points_ids'] ) ) ) : array();
				if ( ! empty( $all_id ) && is_array( $all_id ) ) {
					foreach ( $all_id as $key => $value ) {
						delete_user_meta( $value, 'mwb_wpr_points' );
					}
				}
			}
		}
	}

	/**
	 * Returns an associative array containing the bulk action
	 *
	 * @name process_bulk_action.
	 * @return array
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	public function get_bulk_actions() {
		$actions = array(
			'bulk-delete' => __( 'Reset Points', 'woocommerce-ultimate-points-and-rewards' ),
		);
		return $actions;
	}

	/**
	 * Returns an associative array containing the bulk action for sorting.
	 *
	 * @name get_sortable_columns.
	 * @return array
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	public function get_sortable_columns() {
		$sortable_columns = array(
			'user_name'   => array( 'user_name', false ),
			'user_email'  => array( 'user_email', false ),
			'user_points' => array( 'user_points', false ),
		);
		return $sortable_columns;
	}

	/**
	 * Prepare items for sorting.
	 *
	 * @name prepare_items.
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	public function prepare_items() {
		$per_page              = 10;
		$columns               = $this->get_columns();
		$hidden                = array();
		$sortable              = $this->get_sortable_columns();
		$this->_column_headers = array( $columns, $hidden, $sortable );
		$this->process_bulk_action();

		$current_page       = $this->get_pagenum();
		$this->example_data = $this->get_users_points( $current_page, $per_page );
		$data               = $this->example_data;

		usort( $data, array( $this, 'mwb_wpr_usort_reorder' ) );

		$total_items = $this->mwb_total_count;
		$this->items = $data;
		$this->set_pagination_args(
			array(
				'total_items' => $total_items,
				'per_page'    => $per_page,
				'total_pages' => ceil( $total_items / $per_page ),
			)
		);
	}

	/**
	 * Return sorted associative array.
	 *
	 * @param      string $cloumna       Data.
	 * @param      string $cloumnb       Data.
	 * @name mwb_wpr_usort_reorder.
	 * @return array
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	public function mwb_wpr_usort_reorder( $cloumna, $cloumnb ) {

		$orderby = ( ! empty( $_REQUEST['orderby'] ) ) ? sanitize_text_field( wp_unslash( $_REQUEST['orderby'] ) ) : 'id';
		$order   = ( ! empty( $_REQUEST['order'] ) ) ? sanitize_text_field( wp_unslash( $_REQUEST['order'] ) ) : 'desc';
		if ( is_numeric( $cloumna[ $orderby ] ) && is_numeric( $cloumnb[ $orderby ] ) ) {
			if ( $cloumna[ $orderby ] == $cloumnb[ $orderby ] ) {
				return 0;
			} elseif ( $cloumna[ $orderby ] < $cloumnb[ $orderby ] ) {
				$result = -1;
				return ( 'asc' === $order ) ? $result : -$result;
			} elseif ( $cloumna[ $orderby ] > $cloumnb[ $orderby ] ) {
				$result = 1;
				return ( 'asc' === $order ) ? $result : -$result;
			}
		} else {
			$result = strcmp( $cloumna[ $orderby ], $cloumnb[ $orderby ] );
			return ( 'asc' === $order ) ? $result : -$result;
		}
	}

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 *
	 * @param      string $item       Data.
	 */
	public function column_cb( $item ) {
		return sprintf(
			'<input type="checkbox" name="mpr_points_ids[]" value="%s" />',
			$item['id']
		);
	}

	/**
	 * This function gives points to user if he doesnot get points.
	 *
	 * @name get_users_points.
	 *
	 * @param      string $current_page       Data.
	 * @param      string $per_page      Data.
	 * @return array
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */
	public function get_users_points( $current_page, $per_page ) {

		$args['number'] = $per_page;
		$args['offset'] = ( $current_page - 1 ) * $per_page;
		$args['fields'] = array( 'ID', 'user_login', 'user_email' );
		if ( isset( $_REQUEST['s'] ) ) {
			$args['search'] = '*' . sanitize_text_field( wp_unslash( $_REQUEST['s'] ) ) . '*';
		}
		$args['role__in'] = array( 'subscriber', 'customer', 'administrator', 'editor', 'author', 'contributor' );

		/**
		 * Filters the query arguments used to retrieve users for the current users list table.
		 *
		 * @since 4.4.0
		 *
		 * @param array $args Arguments passed to WP_User_Query to retrieve items for the current
		 *                    Points log Table
		 */
		$args        = apply_filters( 'mwb_points_users_list_table_query_args', $args );
		$user_data   = new WP_User_Query( $args );
		$total_count = $user_data->get_total();
		$user_data   = $user_data->get_results();
		$points_data = array();
		foreach ( $user_data as $key => $value ) {
			$points_data[] = array(
				'id'          => $value->ID,
				'user_name'   => $value->user_login,
				'user_email'  => $value->user_email,
				'user_points' => ! empty( get_user_meta( $value->ID, 'mwb_wpr_points', true ) ) ? get_user_meta( $value->ID, 'mwb_wpr_points', true ) : 0,
			);
		}
		$this->mwb_total_count = $total_count;
		return $points_data;
	}
}

$mwb_wpr_import_nonce = ! empty( $_POST['mwb_wpr_import_nonce'] ) ? sanitize_text_field( wp_unslash( $_POST['mwb_wpr_import_nonce'] ) ) : '';
if ( wp_verify_nonce( $mwb_wpr_import_nonce, 'mwb-import-nonce' ) ) {
	if ( isset( $_POST['mwb_wpr_import_user'] ) ) {

		$import_user = get_option( 'mwb_wpr_user_imported', false );
		if ( false === $import_user ) {

			$user_data             = get_users();
			$points_data           = array();
			$flag                  = false;
			$general_settings      = get_option( 'mwb_wpr_settings_gallery', true );
			$coupon_settings_array = get_option( 'mwb_wpr_coupons_gallery', array() );
			foreach ( $user_data as $key => $value ) {
				$check_user = get_user_meta( $value->data->ID, 'mwb_wpr_points', false );

				if ( false === $check_user ) {

					$today_date                       = date_i18n( 'Y-m-d h:i:sa' );
					$mwb_signup_value                 = isset( $general_settings['mwb_signup_value'] ) ? intval( $general_settings['mwb_signup_value'] ) : 1;
					$import_points['import_points'][] = array(
						'import_points' => $mwb_signup_value,
						'date'          => $today_date,
					);

					update_user_meta( $value->data->ID, 'mwb_wpr_points', $mwb_signup_value );
					update_user_meta( $value->data->ID, 'points_details', $import_points );
					$flag                      = true;
					$mwb_wpr_notificatin_array = get_option( 'mwb_wpr_notificatin_array', true );
					if ( is_array( $mwb_wpr_notificatin_array ) && ! empty( $mwb_wpr_notificatin_array ) ) {
						$mwb_per_currency_spent_value = isset( $coupon_settings_array['mwb_wpr_coupon_conversion_points'] ) ? intval( $coupon_settings_array['mwb_wpr_coupon_conversion_points'] ) : 1;
						$mwb_comment_value            = isset( $general_settings['mwb_comment_value'] ) ? intval( $general_settings['mwb_comment_value'] ) : 1;
						$mwb_refer_value              = isset( $general_settings['mwb_refer_value'] ) ? intval( $general_settings['mwb_refer_value'] ) : 1;
						$mwb_wpr_notificatin_enable   = isset( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) ? intval( $mwb_wpr_notificatin_array['mwb_wpr_notificatin_enable'] ) : 0;
						$mwb_wpr_email_subject        = isset( $mwb_wpr_notificatin_array['mwb_wpr_signup_email_subject'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_signup_email_subject'] : '';
						$mwb_wpr_email_discription    = isset( $mwb_wpr_notificatin_array['mwb_wpr_signup_email_discription_custom_id'] ) ? $mwb_wpr_notificatin_array['mwb_wpr_signup_email_discription_custom_id'] : '';
						$mwb_wpr_email_discription    = str_replace( '[Points]', $mwb_signup_value, $mwb_wpr_email_discription );
						$mwb_wpr_email_discription    = str_replace( '[Total Points]', $mwb_signup_value, $mwb_wpr_email_discription );
						$mwb_wpr_email_discription    = str_replace( '[Comment Points]', $mwb_comment_value, $mwb_wpr_email_discription );
						$mwb_wpr_email_discription    = str_replace( '[Refer Points]', $mwb_refer_value, $mwb_wpr_email_discription );
						$mwb_wpr_email_discription    = str_replace( '[Per Currency Spent Points]', $mwb_per_currency_spent_value, $mwb_wpr_email_discription );
						if ( $mwb_wpr_notificatin_enable ) {
							$headers = array( 'Content-Type: text/html; charset=UTF-8' );
							wc_mail( $value->data->user_email, $mwb_wpr_email_subject, $mwb_wpr_email_discription, $headers );
						}
					}
				}
			}
			if ( $flag ) {

				update_option( 'mwb_wpr_user_imported', true );
			}
		} else {
			update_option( 'check', '' );
		}
	}
}

if ( isset( $_GET['action'] ) && isset( $_GET['user_id'] ) ) {
	if ( 'view' === $_GET['action'] ) {
		$user_log_id = sanitize_text_field( wp_unslash( $_GET['user_id'] ) );
		$user_log    = get_user_meta( $user_log_id, 'mwb_wpr_user_log', true );
		?>
			<h1 class="wp-heading-inline" id="mwb_wpr_points_table_heading"><?php esc_html_e( 'User Coupon Details', 'woocommerce-ultimate-points-and-rewards' ); ?></h1>
			<?php
			if ( isset( $user_log ) && is_array( $user_log ) && null !== $user_log ) {
				?>
				<table class="form-table mwp_wpr_settings mwb_wpr_points_view">
					<thead>
						<tr valign="top">
							<th scope="row" class="titledesc">
								<span class="nobr"><?php echo esc_html_e( 'Points', 'woocommerce-ultimate-points-and-rewards' ); ?></span>
							</th>
							<th scope="row" class="titledesc">
								<span class="nobr"><?php echo esc_html_e( 'Coupon Code', 'woocommerce-ultimate-points-and-rewards' ); ?></span>
							</th>
							<th scope="row" class="titledesc">
								<span class="nobr"><?php echo esc_html_e( 'Coupon Amount', 'woocommerce-ultimate-points-and-rewards' ); ?></span>
							</th>
							<th scope="row" class="titledesc">
								<span class="nobr"><?php echo esc_html_e( 'Amount Left', 'woocommerce-ultimate-points-and-rewards' ); ?></span>
							</th>
							<th scope="row" class="titledesc">
								<span class="nobr"><?php echo esc_html_e( 'Expiry', 'woocommerce-ultimate-points-and-rewards' ); ?></span>
							</th>
						</tr>
					</thead>
					<tbody>
						<?php foreach ( $user_log as $key => $mwb_user_log ) : ?>

							<tr valign="top">
								<?php foreach ( $mwb_user_log as $column_id => $column_name ) : ?>
									<td class="forminp forminp-text">
										<?php
										$mwb_split   = explode( '#', $key );
										if ( 'left' === $column_id ) {
											$column_name = get_post_meta( $mwb_split[1], 'mwb_coupon_static_amount', true );
											echo esc_html( get_woocommerce_currency_symbol() ) . esc_attr( $column_name );
										} elseif ( 'expiry' === $column_id ) {
											if ( WC()->version < '3.0.6' ) {

												$column_name = get_post_meta( $mwb_split[1], 'expiry_date', true );
												echo esc_attr( $column_name );
											} else {
												$column_name = get_post_meta( $mwb_split[1], 'date_expires', true );
												$dt = new DateTime( "@$column_name" );
												echo wp_kses_post( $dt->format( 'Y-m-d' ) );
											}
										} else {
											echo esc_html( $column_name );
										}
										?>
									</td>
								<?php endforeach; ?>
							</tr>
						<?php endforeach; ?>
					</tbody>
				</table>
				<?php
			} else {
				echo '<h2>' . esc_html_e( 'No Coupons Generated Yet.', 'woocommerce-ultimate-points-and-rewards' ) . '<h2>';
			}
			?>
		<br>
		<a href="<?php echo esc_url( MWB_WPR_HOME_URL ); ?>admin.php?page=mwb-wpr-setting&tab=mwb_wpr_points_table" style="line-height: 2" class="button button-primary mwb_wpr_save_changes"><?php esc_html_e( 'Go Back', 'woocommerce-ultimate-points-and-rewards' ); ?></a> 
		<?php
	} elseif ( 'view_point_log' === $_GET['action'] ) {
		$user_id      = sanitize_text_field( wp_unslash( $_GET['user_id'] ) );
		$point_log    = get_user_meta( $user_id, 'points_details', true );
		$total_points = get_user_meta( $user_id, 'mwb_wpr_points', true )
		?>
			<h1 class="wp-heading-inline" id="mwb_wpr_points_table_heading"><?php esc_html_e( 'User Point Log Details', 'woocommerce-ultimate-points-and-rewards' ); ?></h1>
			<?php
			if ( isset( $point_log ) && is_array( $point_log ) && null !== $point_log ) {
				?>
				<div class="mwb_wpr_wrapper_div">
					<table class="form-table mwp_wpr_settings mwb_wpr_points_view">
						<thead>
							<tr valign="top">
								<th scope="row" class="titledesc">
									<span class="nobr"><?php echo esc_html_e( 'Date & Time', 'woocommerce-ultimate-points-and-rewards' ); ?></span>
								</th>
								<th scope="row" class="titledesc">
									<span class="nobr"><?php echo esc_html_e( 'Point Status', 'woocommerce-ultimate-points-and-rewards' ); ?></span>
								</th>
								<th scope="row" class="titledesc">
									<span class="nobr"><?php echo esc_html_e( 'Activity', 'woocommerce-ultimate-points-and-rewards' ); ?></span>
								</th>
							</tr>
						</thead>
					</table>
					<?php
					if ( array_key_exists( 'registration', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Signup Event', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
								<tr valign="top">
									<td class="forminp forminp-text"><?php echo wp_kses_post( $point_log['registration']['0']['date'] ); ?></td>
									<td class="forminp forminp-text"><?php echo '+' . wp_kses_post( $point_log['registration']['0']['registration'] ); ?></td>
									<td class="forminp forminp-text"><?php esc_html_e( 'Registration Points', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
								</tr>
							</table>
						</div>
						<?php
					}
					if ( array_key_exists( 'import_points', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Signup Event', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
								<tr valign="top">
									<td class="forminp forminp-text"><?php echo wp_kses_post( $point_log['import_points']['0']['date'] ); ?></td>
									<td class="forminp forminp-text"><?php echo '+' . wp_kses_post( $point_log['import_points']['0']['import_points'] ); ?></td>
									<td class="forminp forminp-text"><?php esc_html_e( 'Registration Points', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
								</tr>
							</table>
						</div>
						<?php
					}
					if ( array_key_exists( 'Coupon_details', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Coupon Generation', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
									<?php
									foreach ( $point_log['Coupon_details'] as $key => $value ) {
										?>
									<tr valign="top">
										<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
										<td class="forminp forminp-text"><?php echo '-' . esc_html( $value['Coupon_details'] ); ?></td>
										<td class="forminp forminp-text"><?php esc_html_e( 'Coupon Points', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
									</tr>
										<?php
									}
									?>
							</table>
						</div> 
						<?php
					}
					if ( array_key_exists( 'points_on_order', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Points on Order', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table"> 
							<?php
							foreach ( $point_log['points_on_order'] as $key => $value ) {
								?>
									<tr valign="top">
										<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
										<td class="forminp forminp-text"><?php echo '+' . esc_html( $value['points_on_order'] ); ?></td>
										<td class="forminp forminp-text"><?php esc_html_e( 'Points earned on Order Total', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
									</tr>
								<?php
							}
							?>
							</table>
						</div>
										<?php
					}
					if ( array_key_exists( 'product_details', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Assigned Product Point', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table"> 
							<?php
							foreach ( $point_log['product_details'] as $key => $value ) {
								?>
									<tr valign="top">
										<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
										<td class="forminp forminp-text"><?php echo '+' . esc_html( $value['product_details'] ); ?></td>
										<td class="forminp forminp-text"><?php esc_html_e( 'Product purchase Points', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
									</tr>
								<?php
							}
							?>
							</table>
						</div>
						<?php
					}
					if ( array_key_exists( 'pro_conversion_points', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Order Total Points', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
						<?php
						foreach ( $point_log['pro_conversion_points'] as $key => $value ) {
							?>
									<tr valign="top">
										<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
										<td class="forminp forminp-text"><?php echo '+' . esc_html( $value['pro_conversion_points'] ); ?></td>
										<td class="forminp forminp-text"><?php esc_html_e( 'Product Conversion Points', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
									</tr>
							<?php
						}
						?>
							</table>
						</div> 
						<?php
					}
					if ( array_key_exists( 'comment', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Product Review Point', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
							<?php
							foreach ( $point_log['comment'] as $key => $value ) {
								?>
									<tr valign="top">
										<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
										<td class="forminp forminp-text"><?php echo '+' . esc_html( $value['comment'] ); ?></td>
										<td class="forminp forminp-text"><?php esc_html_e( 'Comment Points', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
									</tr>
								<?php
							}
							?>
							</table>
						</div>
						<?php
					}
					if ( array_key_exists( 'daily__login', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Points earned via daily login', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
							<?php
							foreach ( $point_log['daily__login'] as $key => $value ) {
								?>
									<tr valign="top">
										<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
										<td class="forminp forminp-text"><?php echo '+' . esc_html( $value['daily__login'] ); ?></td>
										<td class="forminp forminp-text"><?php esc_html_e( 'Daily login Points', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
									</tr>
								<?php
							}
							?>
							</table>
						</div>
						<?php
					}
					if ( array_key_exists( 'reward__order_points', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Points earned via number of order place', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
							<?php
							foreach ( $point_log['reward__order_points'] as $key => $value ) {
								?>
									<tr valign="top">
										<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
										<td class="forminp forminp-text"><?php echo '+' . esc_html( $value['reward__order_points'] ); ?></td>
										<td class="forminp forminp-text"><?php esc_html_e( 'Order Rewards Points', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
									</tr>
								<?php
							}
							?>
							</table>
						</div>
						<?php
					}
					if ( array_key_exists( 'points_transfer_to_wallet', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Points Transfer to Wallet', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
							<?php
							foreach ( $point_log['points_transfer_to_wallet'] as $key => $value ) {
								?>
									<tr valign="top">
										<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
										<td class="forminp forminp-text"><?php echo '-' . esc_html( $value['points_transfer_to_wallet'] ); ?></td>
										<td class="forminp forminp-text"><?php esc_html_e( 'Points to wallet', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
									</tr>
								<?php
							}
							?>
							</table>
						</div>
						<?php
					}
					if ( array_key_exists( 'subscription_renewal_rewards_points', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Subscription renewal points added', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
							<?php
							foreach ( $point_log['subscription_renewal_rewards_points'] as $key => $value ) {
								?>
									<tr valign="top">
										<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
										<td class="forminp forminp-text"><?php echo '+' . esc_html( $value['subscription_renewal_rewards_points'] ); ?></td>
										<td class="forminp forminp-text"><?php esc_html_e( 'Subs renewal points', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
									</tr>
								<?php
							}
							?>
							</table>
						</div>
						<?php
					}
					if ( array_key_exists( 'refund_subs_points', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Subscription renewal points refunded', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
							<?php
							foreach ( $point_log['refund_subs_points'] as $key => $value ) {
								?>
									<tr valign="top">
										<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
										<td class="forminp forminp-text"><?php echo '-' . esc_html( $value['refund_subs_points'] ); ?></td>
										<td class="forminp forminp-text"><?php esc_html_e( 'Subs points deducted', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
									</tr>
								<?php
							}
							?>
							</table>
						</div>
						<?php
					}
					if ( array_key_exists( 'purchase_through_only_refunded', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Refunded points by purchase through points only', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
							<?php
							foreach ( $point_log['purchase_through_only_refunded'] as $key => $value ) {
								?>
									<tr valign="top">
										<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
										<td class="forminp forminp-text"><?php echo '+' . esc_html( $value['purchase_through_only_refunded'] ); ?></td>
										<td class="forminp forminp-text"><?php esc_html_e( 'Purchase only points', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
									</tr>
								<?php
							}
							?>
							</table>
						</div>
						<?php
					}
					if ( array_key_exists( 'membership', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Membership Points', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
						<?php
						foreach ( $point_log['membership'] as $key => $value ) {
							?>
									<tr valign="top">
										<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
										<td class="forminp forminp-text"><?php echo '-' . esc_html( $value['membership'] ); ?></td>
										<td class="forminp forminp-text"><?php esc_html_e( 'Membership Points', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
									</tr>
							<?php
						}
						?>
							</table>
						</div>
						<?php
					}
					if ( array_key_exists( 'reference_details', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Referral Earns', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
							<?php
							foreach ( $point_log['reference_details'] as $key => $value ) {
								$user_name = '';
								if ( isset( $value['refered_user'] ) && ! empty( $value['refered_user'] ) ) {
									$user      = get_user_by( 'ID', $value['refered_user'] );
									$user_name = $user->user_nicename;
								}
								?>
									<tr valign="top">
										<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
										<td class="forminp forminp-text"><?php echo '+' . esc_html( $value['reference_details'] ); ?></td>
										<td class="forminp forminp-text">
										<?php
										esc_html_e( 'Reference Points by ', 'woocommerce-ultimate-points-and-rewards' );
										echo esc_html( $user_name );
										?>
										</td>
									</tr>
								<?php
							}
							?>
							</table>
						</div>
						<?php
					}
					if ( array_key_exists( 'ref_product_detail', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Referral Purchase Point', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
						<?php
						foreach ( $point_log['ref_product_detail'] as $key => $value ) {
							?>
							<tr valign="top">
								<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
								<td class="forminp forminp-text"><?php echo '+' . esc_html( $value['ref_product_detail'] ); ?></td>
								<td class="forminp forminp-text"><?php esc_html_e( 'Product purchased by Referred User Points', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
							</tr>
							<?php
						}
						?>
							</table>
						</div>
						<?php
					}
					if ( array_key_exists( 'admin_points', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Admin Updates', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
							<?php
							foreach ( $point_log['admin_points'] as $key => $value ) {
								$value['sign']   = isset( $value['sign'] ) ? $value['sign'] : '';
								$value['reason'] = isset( $value['reason'] ) ? $value['reason'] : __( 'Updated By Admin', 'woocommerce-ultimate-points-and-rewards' );
								?>
									<tr valign="top">
										<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
										<td class="forminp forminp-text"><?php echo wp_kses_post( $value['sign'] . $value['admin_points'] ); ?></td>
										<td class="forminp forminp-text"><?php echo esc_html( $value['reason'] ); ?></td>
									</tr>
								<?php
							}
							?>
							</table>
						</div>
						<?php
					}
					if ( array_key_exists( 'pur_by_points', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Product has been purchased using points', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
							<?php
							foreach ( $point_log['pur_by_points'] as $key => $value ) {
								?>
									<tr valign="top">
										<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
										<td class="forminp forminp-text"><?php echo '-' . esc_html( $value['pur_by_points'] ); ?></td>
										<td class="forminp forminp-text"><?php esc_html_e( 'Purchased through Points', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
									</tr>
								<?php
							}
							?>
							</table>
						</div> 
						<?php
					}
					if ( array_key_exists( 'deduction_of_points', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Deduction of points for return request', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
						<?php
						foreach ( $point_log['deduction_of_points'] as $key => $value ) {
							?>
							<tr valign="top">
								<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
								<td class="forminp forminp-text"><?php echo '-' . esc_html( $value['deduction_of_points'] ); ?></td>
								<td class="forminp forminp-text"><?php esc_html_e( 'Deduct Points', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
							</tr>
							<?php
						}
						?>
							</table>
						</div> 
						<?php
					}
					if ( array_key_exists( 'return_pur_points', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Return Points', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
							<?php
							foreach ( $point_log['return_pur_points'] as $key => $value ) {
								?>
								<tr valign="top">
									<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
									<td class="forminp forminp-text"><?php echo '+' . esc_html( $value['return_pur_points'] ); ?></td>
									<td class="forminp forminp-text"><?php esc_html_e( 'Returned Points', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
								</tr>
								<?php
							}
							?>
							</table>
						</div>
								<?php
					}
					if ( array_key_exists( 'deduction_currency_spent', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Deduct Order Total Points', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table"> 
							<?php
							foreach ( $point_log['deduction_currency_spent'] as $key => $value ) {
								?>
								<tr valign="top">
									<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
									<td class="forminp forminp-text"><?php echo '-' . esc_html( $value['deduction_currency_spent'] ); ?></td>
									<td class="forminp forminp-text"><?php esc_html_e( 'Deduct Per Currency Spent Point', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
								</tr>
								<?php
							}
							?>
							</table>
						</div>
						<?php
					}
					if ( array_key_exists( 'Sender_point_details', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Shared with', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table"> 
						<?php
						foreach ( $point_log['Sender_point_details'] as $key => $value ) {
							$user_name = '';
							if ( isset( $value['give_to'] ) && ! empty( $value['give_to'] ) ) {
								$user      = get_user_by( 'ID', $value['give_to'] );
								$user_name = $user->user_nicename;
							}
							?>
							<tr valign="top">
								<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
								<td class="forminp forminp-text"><?php echo '-' . esc_html( $value['Sender_point_details'] ); ?></td>
								<td class="forminp forminp-text">
								<?php
								esc_html_e( 'Shared to ', 'woocommerce-ultimate-points-and-rewards' );
								echo esc_html( $user_name );
								?>
								</td>
							</tr>
							<?php
						}
						?>
							</table>
						</div>
								<?php
					}
					if ( array_key_exists( 'Receiver_point_details', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Receives Points', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
						<?php
						foreach ( $point_log['Receiver_point_details'] as $key => $value ) {
							$user_name = '';
							if ( isset( $value['received_by'] ) && ! empty( $value['received_by'] ) ) {
								$user      = get_user_by( 'ID', $value['received_by'] );
								$user_name = $user->user_nicename;
							}
							?>
							<tr valign="top">
								<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
								<td class="forminp forminp-text"><?php echo '+' . esc_html( $value['Receiver_point_details'] ); ?> </td>
								<td class="forminp forminp-text">
								<?php
								esc_html_e( 'Received Points by ', 'woocommerce-ultimate-points-and-rewards' );
								echo esc_html( $user_name );
								?>
								</td>
							</tr>
							<?php
						}
						?>
							</table>
						</div>
						<?php
					}
					if ( array_key_exists( 'cart_subtotal_point', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Points Applied on Cart', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
							<?php
							foreach ( $point_log['cart_subtotal_point'] as $key => $value ) {
								?>
								<tr valign="top">
									<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
									<td class="forminp forminp-text"><?php echo esc_html( $value['cart_subtotal_point'] ); ?> </td>
									<td class="forminp forminp-text"><?php esc_html_e( 'Points Used on Cart Subtotal', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
								</tr>
								<?php
							}
							?>
							</table>
						</div>
						<?php
					}
					if ( array_key_exists( 'refund_applied_cart_point', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Applied points on cart/checkout refunded successfully', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
							<?php
							foreach ( $point_log['refund_applied_cart_point'] as $key => $value ) {
								?>
									<tr valign="top">
										<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
										<td class="forminp forminp-text"><?php echo '+' . esc_html( $value['refund_applied_cart_point'] ); ?> </td>
										<td class="forminp forminp-text"><?php esc_html_e( 'Applied Points Refund', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
									</tr>
								<?php
							}
							?>
							</table>
						</div>
						<?php
					}
					if ( array_key_exists( 'expired_details', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Expired Points', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
							<?php
							foreach ( $point_log['expired_details'] as $key => $value ) {
								?>
									<tr valign="top">
										<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
										<td class="forminp forminp-text"><?php echo '-' . esc_html( $value['expired_details'] ); ?></td>
										<td class="forminp forminp-text"><?php esc_html_e( 'Get Expired', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
									</tr>
								<?php
							}
							?>
							</table>
						</div>
						<?php
					}
					if ( array_key_exists( 'deduct_currency_pnt_cancel', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Order Points Deducted due to Cancelation of Order', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
							<?php
							foreach ( $point_log['deduct_currency_pnt_cancel'] as $key => $value ) {
								?>
									<tr valign="top">
										<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
										<td class="forminp forminp-text"><?php echo '-' . esc_html( $value['deduct_currency_pnt_cancel'] ); ?></td>
										<td class="forminp forminp-text"><?php esc_html_e( 'Deducted Points', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
									</tr>
								<?php
							}
							?>
							</table>
						</div>
								<?php
					}
					if ( array_key_exists( 'deduct_bcz_cancel', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Assigned Points Deducted due to Cancelation of Order', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
						<?php
						foreach ( $point_log['deduct_bcz_cancel'] as $key => $value ) {
							?>
									<tr valign="top">
										<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
										<td class="forminp forminp-text"><?php echo '-' . esc_html( $value['deduct_bcz_cancel'] ); ?></td>
										<td class="forminp forminp-text"><?php esc_html_e( 'Deducted Points', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
									</tr>
										<?php
						}
						?>
							</table>
						</div>
						<?php
					}
					if ( array_key_exists( 'pur_points_cancel', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Points Returned due to Cancelation of Order', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
						<?php
						foreach ( $point_log['pur_points_cancel'] as $key => $value ) {
							?>
								<tr valign="top">
									<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
									<td class="forminp forminp-text"><?php echo '+' . esc_html( $value['pur_points_cancel'] ); ?></td>
									<td class="forminp forminp-text"><?php esc_html_e( 'Returned Points', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
								</tr>
							<?php
						}
						?>
							</table>
						</div>
						<?php
					}
					// MWB CUSTOM CODE.
					if ( array_key_exists( 'pur_pro_pnt_only', $point_log ) ) {
						?>
						<div class="mwb_wpr_slide_toggle">
							<p class="mwb_wpr_view_log_notice mwb_wpr_common_slider"><?php esc_html_e( 'Points Applied on Cart', 'woocommerce-ultimate-points-and-rewards' ); ?>
								<a class="mwb_wpr_open_toggle" href="javascript:;"></a>
							</p>
							<table class="form-table mwp_wpr_settings mwb_wpr_points_view mwb_wpr_common_table">
						<?php
						foreach ( $point_log['pur_pro_pnt_only'] as $key => $value ) {
							?>
							<tr valign="top">
								<td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
								<td class="forminp forminp-text"><?php echo '-' . esc_html( $value['pur_pro_pnt_only'] ); ?> </td>
								<td class="forminp forminp-text"><?php esc_html_e( 'Product Purchased by Points', 'woocommerce-ultimate-points-and-rewards' ); ?></td>
							</tr>
							<?php
						}
						?>
							</table>
						</div>
						<?php
					}
					// END OF MWB CUSTOM CODE.
					?>

					<table class="form-table mwp_wpr_settings mwb_wpr_points_view">
						<tr valign="top">
							<td class="forminp forminp-text"><strong><?php esc_html_e( 'Total Points', 'woocommerce-ultimate-points-and-rewards' ); ?></strong></td>
							<td class="forminp forminp-text"><strong><?php echo esc_html( $total_points ); ?></strong>
							</td>
							<td class="forminp forminp-text"></td>
						</tr>
					</table>
				</div>
				<?php
			} else {
				echo '<h2>' . esc_html__( 'No Points Generated Yet.', 'woocommerce-ultimate-points-and-rewards' ) . '<h2>';
			}
	}
} else {
	?>
		<h1 class="wp-heading-inline" id="mwb_wpr_points_table_heading"><?php esc_html_e( 'Points Table', 'woocommerce-ultimate-points-and-rewards' ); ?></h1>
		<?php
		//phpcs:enable.
		$general_settings  = get_option( 'mwb_wpr_settings_gallery', true );
		$enable_mwb_signup = isset( $general_settings['enable_mwb_signup'] ) ? intval( $general_settings['enable_mwb_signup'] ) : 0;
		if ( $enable_mwb_signup ) {
				$import_user = get_option( 'mwb_wpr_user_imported', false );

			if ( false === $import_user ) {
				?>
				<div class="mwb_wpr_import_user container">
					<h3>
					<?php esc_html_e( 'Import Users', 'woocommerce-ultimate-points-and-rewards' ); ?>
					</h3>
					<p>
					<?php esc_html_e( 'Import existing users and assign them with Sign Up Points', 'woocommerce-ultimate-points-and-rewards' ); ?>
					</p>
					<input type="submit" value="<?php esc_html_e( 'Import', 'woocommerce-ultimate-points-and-rewards' ); ?>" id="mwb_wpr_import" class="page-title-action button button-primary button-large mwb_wpr_save_changes" name="mwb_wpr_import_user">
				</div>

				<?php
			} else {
				$args['role__in'] = array( 'subscriber', 'customer', 'administrator', 'editor', 'author', 'contributor' );

				$user_data  = get_users( $args );
				$guest_flag = false;
				foreach ( $user_data as $key => $value ) {
					$user_id      = $value->data->ID;
					$guest_points = get_user_meta( $value->data->ID, 'mwb_wpr_points', false );

					if ( false === $guest_points ) {
						$guest_flag = true;
					}
				}
				if ( $guest_flag ) {
					?>
					<div class="mwb_wpr_import_user container">
						<h3>
					<?php esc_html_e( 'Import Users', 'woocommerce-ultimate-points-and-rewards' ); ?>
						</h3>
						<p>
							<?php esc_html_e( 'Import existing users and assign them with Sign Up Points', 'woocommerce-ultimate-points-and-rewards' ); ?>
						</p>
						<input type="hidden" name="mwb_wpr_import_nonce" value="<?php echo esc_html( wp_create_nonce( 'mwb-import-nonce' ) ); ?>" >
						<input type="button" value="<?php esc_html_e( 'Import', 'woocommerce-ultimate-points-and-rewards' ); ?>" id="mwb_wpr_import" class="page-title-action button button-primary button-large mwb_wpr_save_changes" name="mwb_wpr_import_user">
					</div>

					<?php
					update_option( 'mwb_wpr_user_imported', false );
				}
			}
		}
		?>
		<?php require 'mwb-import-users-points.php'; ?>
		<form method="post">
			<input type="hidden" name="page" value="<?php esc_html_e( 'points_log_list_table', 'woocommerce-ultimate-points-and-rewards' ); ?>">
			<?php
			$my_list_table = new Mwb_Points_Table();
			$my_list_table->prepare_items();
			$my_list_table->search_box( __( 'Search Users', 'woocommerce-ultimate-points-and-rewards' ), 'mwb-wpr-user' );
			$my_list_table->display();
			?>
		</form>
	<?php
}
