<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link  https://makewebbetter.com/
 * @since 1.0.0
 *
 * @package    Woocommerce_Ultimate_Points_And_Rewards
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}

/**
 * This is construct of class where all users point listed.
 *
 * @name Points_Log_List_Table
 * @category Class
 * @author makewebbetter<webmaster@makewebbetter.com>
 * @link http://www.makewebbetter.com/
 */
class Points_Log_List_Table extends WP_List_Table {

	/**
	 * Public variable.
	 *
	 * @var [type]
	 */
	public $example_data;

	/**
	 * This construct colomns in point table.
	 *
	 * @name get_columns.
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link http://www.makewebbetter.com/
	 */
	public function get_columns() {

		$columns = array(
			'cb'          => '<input type="checkbox" />',
			'user_name'   => __( 'User Name', 'woocommerce-ultimate-points-and-rewards' ),
			'user_email'  => __( 'User Email', 'woocommerce-ultimate-points-and-rewards' ),
			'user_points' => __( 'User Points', 'woocommerce-ultimate-points-and-rewards' ),
			'user_level'  => __( 'Level', 'woocommerce-ultimate-points-and-rewards' ),
		);
		return $columns;
	}

	/**
	 * This show points table list.
	 *
	 * @param      string $item       Data.
	 * @param      string $column_name       Data.
	 * @name column_default.
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link http://www.makewebbetter.com/
	 */
	public function column_default( $item, $column_name ) {

		switch ( $column_name ) {
			case 'user_name':
				return $item[ $column_name ];
			case 'user_email':
				return '<b>' . $item[ $column_name ] . '</b>';
			case 'user_points':
				return '<b>' . $item[ $column_name ] . '</b>';
			case 'user_level':
				return '<b>' . $item[ $column_name ] . '</b>';

			default:
				return false;
		}
	}

	/**
	 * Perform admin bulk action setting for points table.
	 *
	 * @name process_bulk_action.
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link http://www.makewebbetter.com/
	 */
	public function process_bulk_action() {

		if ( 'bulk-delete' === $this->current_action() ) {
			if ( isset( $_POST['membership_delete_nonce'] ) && ! empty( $_POST['membership_delete_nonce'] ) ) {
				$membership_delete_nonce = ! empty( $_POST['membership_delete_nonce'] ) ? sanitize_text_field( wp_unslash( $_POST['membership_delete_nonce'] ) ) : '';

				if ( wp_verify_nonce( $membership_delete_nonce, 'member-delete-nonce' ) ) {
					$all_id = ! empty( $_POST['mpr_points_ids'] ) && is_array( $_POST['mpr_points_ids'] ) ? map_deep( wp_unslash( $_POST['mpr_points_ids'] ), 'sanitize_text_field' ) : '';

					if ( ! empty( $all_id ) && is_array( $all_id ) ) {
						foreach ( $all_id as $key => $value ) {
							delete_user_meta( $value, 'membership_level' );
						}
					}
				}
			}
		}
	}

	/**
	 * Returns an associative array containing the bulk action
	 *
	 * @name process_bulk_action.
	 * @return array
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link http://www.makewebbetter.com/
	 */
	public function get_bulk_actions() {
		$actions = array(
			'bulk-delete' => __( 'Delete', 'woocommerce-ultimate-points-and-rewards' ),
		);
		return $actions;
	}

	/**
	 * Returns an associative array containing the bulk action for sorting.
	 *
	 * @name get_sortable_columns.
	 * @return array
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link http://www.makewebbetter.com/
	 */
	public function get_sortable_columns() {
		$sortable_columns = array(
			'user_name'   => array( 'user_name', false ),
			'user_email'  => array( 'user_email', false ),
			'user_points' => array( 'user_points', false ),
		);
		return $sortable_columns;
	}

	/**
	 * Prepare items for sorting.
	 *
	 * @name prepare_items.
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link http://www.makewebbetter.com/
	 */
	public function prepare_items() {
		$per_page              = 10;
		$columns               = $this->get_columns();
		$hidden                = array();
		$sortable              = $this->get_sortable_columns();
		$this->_column_headers = array( $columns, $hidden, $sortable );
		$this->process_bulk_action();

		$this->example_data = $this->get_users_points();
		$data               = $this->example_data;
		$tst                = usort( $data, array( $this, 'mwb_wpr_usort_reorder' ) );
		$current_page       = $this->get_pagenum();
		$total_items        = count( $data );
		$data               = array_slice( $data, ( ( $current_page - 1 ) * $per_page ), $per_page );
		$this->items        = $data;
		$this->set_pagination_args(
			array(
				'total_items' => $total_items,
				'per_page'    => $per_page,
				'total_pages' => ceil( $total_items / $per_page ),
			)
		);

	}

	/**
	 * Return sorted associative array.
	 *
	 * @param      string $cloumna       Data.
	 * @param      string $cloumnb       Data.
	 * @name mwb_wpr_usort_reorder.
	 * @return array
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link http://www.makewebbetter.com/
	 */
	public function mwb_wpr_usort_reorder( $cloumna, $cloumnb ) {
		$orderby = ! empty( $_REQUEST['orderby'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['orderby'] ) ) : 'id';
		$order   = ! empty( $_REQUEST['order'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['order'] ) ) : 'desc';
		if ( is_numeric( $cloumna[ $orderby ] ) && is_numeric( $cloumnb[ $orderby ] ) ) {
			if ( $cloumna[ $orderby ] == $cloumnb[ $orderby ] ) {
					return 0;
			} elseif ( $cloumna[ $orderby ] < $cloumnb[ $orderby ] ) {
				$result = -1;
				return ( 'asc' === $order ) ? $result : -$result;
			} elseif ( $cloumna[ $orderby ] > $cloumnb[ $orderby ] ) {
				$result = 1;
				return ( 'asc' === $order ) ? $result : -$result;
			}
		} else {
			$result = strcmp( $cloumna[ $orderby ], $cloumnb[ $orderby ] );
			return ( 'asc' === $order ) ? $result : -$result;
		}
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @param      string $item       Data.
	 * @since    1.0.0
	 */
	public function column_cb( $item ) {
		return sprintf(
			'<input type="checkbox" name="mpr_points_ids[]" value="%s" />
			<input type="hidden" name="membership_delete_nonce" value="%s">',
			$item['id'],
			wp_create_nonce( 'member-delete-nonce' )
		);
	}

	/**
	 * This function gives points to user if he doesnot get points.
	 *
	 * @name get_users_points.
	 * @return array
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link http://www.makewebbetter.com/
	 */
	public function get_users_points() {

		$args['meta_query'] = array(
			'relation' => 'AND',
			array(
				'key'     => 'membership_level',
				'compare' => 'EXISTS',
			),
			array(
				'key' => 'mwb_wpr_points',

			),
		);

		if ( isset( $_REQUEST['s'] ) ) {
			$args['search'] = '*' . sanitize_text_field( wp_unslash( $_REQUEST['s'] ) ) . '*';
		}
		$user_data   = new WP_User_Query( $args );
		$user_data   = $user_data->get_results();
		$points_data = array();
		foreach ( $user_data as $key => $value ) {
			$points_data[] = array(
				'id'          => $value->data->ID,
				'user_name'   => $value->data->user_nicename,
				'user_email'  => $value->data->user_email,
				'user_points' => get_user_meta( $value->data->ID, 'mwb_wpr_points', true ),
				'user_level'  => get_user_meta( $value->data->ID, 'membership_level', true ),
			);
		}
		return $points_data;
	}
}
?>
<form method="post">
	<input type="hidden" name="page" value="<?php esc_html_e( 'points_log_list_table', 'woocommerce-ultimate-points-and-rewards' ); ?>">
	<?php
	$my_list_table = new Points_Log_List_Table();
	$my_list_table->prepare_items();
	$my_list_table->search_box( __( 'Search Users', 'woocommerce-ultimate-points-and-rewards' ), 'mwb-wpr-user' );
	$my_list_table->display();
	?>
</form>

